# coding=utf-8

from __future__ import unicode_literals
from collections import OrderedDict

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    street_suffixes = OrderedDict(
            (('utca', 0.75), ('út', 0.1), ('tér', 0.1), ('köz', 0.001), ('körút', 0.001), ('sétány', 0.001),))

    street_name_formats = ('{{frequent_street_name}} {{street_suffix}}', '{{real_city_name}}i {{street_suffix}}',
                           '{{city_part}}{{city_suffix}}i {{street_suffix}}',
                           '{{city_prefix}}{{city_part}}i {{street_suffix}}')

    #   Currently deprecated.
    #   secondary_address_formats = ("#.em #.", "##. em. #.")


    city_formats = ('{{city_prefix}}{{city_part}}{{city_suffix}}', '{{city_part}}{{city_suffix}}', '{{real_city_name}}')

    street_address_with_county_formats = (
        '{{street_name}} {{building_number}}\n{{county}} megye\n{{postcode}} {{city}}',)

    street_address_formats = ('{{street_name}} {{building_number}}',)

    address_formats = ("{{street_address}}\n{{postcode}} {{city}}",)

    frequent_street_names = (
        'Ady Endre', 'Dózsa György', 'Petőfi', 'Petőfi Sándor', 'Arany János', 'Béke', 'Szabadság', 'Kossuth',
        'József Attila')

    # The 'real city name' generator includes a number of real cities of
    # Hungary that no generator could feasibly dispense. Please note that the
    # post code generator is, at this point, not capable of generating a
    # fitting post code. In Hungary, post codes are determined by the county of
    # the place (see the county generator), and for this reason, often there
    # will be a discrepancy. A patch is in the works - until then, use
    # Wikipedia to resolve postcode issues.
    #
    # This generator was created by collecting the 30 largest Hungarian places
    # by population, based on the Hungarian Gazetteer generated with effect as
    # of 01 January 2016 (http://www.ksh.hu/docs/hun/hnk/hnk_2016.pdf).

    real_city_names = (
        'Budapest', 'Debrecen', 'Szeged', 'Miskolc', 'Pécs', 'Győr', 'Nyíregyháza', 'Kecskemét', 'Székesfehérvár',
        'Szombathely', 'Szolnok', 'Tatabánya', 'Érd', 'Kaposvár', 'Sopron', 'Veszprém', 'Békéscsaba', 'Zalaegerszeg',
        'Eger', 'Nagykanizsa', 'Dunaújváros', 'Hódmezővásárhely', 'Dunakeszi', 'Szigetszentmiklós', 'Cegléd', 'Baja',
        'Salgótarján', 'Ózd', 'Vác', 'Mosonmagyaróvár')

    city_prefs = (
        'kis', 'nagy', 'szent', 'duna', 'tisza', 'alsó', 'felső', 'belső', 'bakony', 'vác', 'mező', 'nyék', 'nyír',
        'balaton', 'borsod', 'buda', 'hajdú', 'kun', 'moson', 'pilis', 'új', 'egyházas', 'dráva', 'magyar', 'mátra',
        'somogy', 'lajos', 'bács', 'békés', 'puszta', 'orosz', 'rác', 'szerb', 'német', 'török')

    city_parts = (
        'híd', 'györgy', 'mindszent', 'kereszt', 'márton', 'hát', 'hetven', 'mellék', 'tamási', 'tapolca', 'fürdő',
        'liget', 'szék', 'tót', '')

    city_suffixes = (
        'háza', 'németi', 'devecser', 'fa', 'nádasd', 'apáti', 'falu', 'falva', 'vég', 'vár', 'vára', 'várad', 'hida',
        'kövesd', 'bánya', 'halas', 'berény', 'kőrös', 'haraszti', 'város')

    counties = (
    'Bács-Kiskun', 'Baranya', 'Békés', 'Borsod-Abaúj-Zemplén', 'Csongrád', 'Fejér', 'Győr-Moson-Sopron', 'Hajdú-Bihar',
    'Heves', 'Jász-Nagykun-Szolnok', 'Komárom-Esztergom', 'Nógrád', 'Pest', 'Somogy', 'Szabolcs-Szatmár-Bereg', 'Tolna',
    'Vas', 'Veszprém', 'Zala')

    countries = (
        "Afganisztán", "Aland-szigetek", "Albánia", "Algéria", "Amerikai Szamoa", "Amerikai Virgin-szigetek", "Andorra",
        "Angola", "Anguilla", "Antarktisz", "Antigua és Barbuda", "Apostoli Szentszék", "Argentína", "Aruba",
        "Ausztrália", "Ausztria", "Amerikai Egyesült Államok Külső Szigetei", "Azerbajdzsán", "Bahama-szigetek",
        "Bahrein", "Banglades", "Barbados", "Fehéroroszország", "Belgium", "Belize", "Benin", "Bermuda", "Bhután",
        "Bissa -Guinea", "Bolívia", "Bosznia-Hercegovina", "Botswana", "Bouvet-sziget", "Brazília",
        "Brit Indiai-óceáni Terület", "Brit Virgin - szigetek", "Brunei", "Bulgária", "Burkina Faso", "Burundi",
        "Chile", "Ciprus", "Comore-szigetek", "Cook-szigetek", "Costa Rica", "Csád", "Csehország", "Dánia",
        "Dél-Afrika", "Dél-Korea", "Dominika", "Dominikai Köztársaság", "Dzsibuti", "Ecuador", "Egyenlítői-Guinea",
        "Egyesült Államok", "Egyesült Arab Emírségek", "Egyesült Királyság", "Egyiptom", "Elefántcsontpart", "Eritrea",
        "Északi Mariana-szigetek", "Észak-Korea", "Észtország", "Etiópia", "Falkland-szigetek", "Feröer szigetek",
        "Fidzsi-szigetek", "Finnország", "Francia Déli Területek", "Francia Guyana", "Francia Polinézia",
        "Franciaország", "Fülöp-szigetek", "Gabon", "Gambia", "Ghána", "Gibraltár", "Görögország", "Grenada",
        "Grönland", "Grúzia", "Guadeloupe", "Guam", "Guatemala", "Guinea", "Guyana", "Haiti", "Holland Antillák",
        "Hollandia", "Honduras", "Hongkong", "Horvátország", "India", "Indonézia", "Irak", "Irán", "Írország", "Izland",
        "Izrael", "Jamaica", "Japán", "Jemen", "Jordánia", "Kajmán-szigetek", "Kambodzsa", "Kamerun", "Kanada",
        "Karácsony-sziget", "Katar", "Kazahsztán", "Kelet-Timor", "Kenya", "Kína", "Kirgizisztán", "Kiribati",
        "Keeling-szigetek", "Kolumbia", "Kongó", "Kongói Demokratikus Köztársaság", "Közép-afrikai Köztársaság", "Kuba",
        "Kuvait", "Laosz", "Lengyelország", "Lesotho", "Lettország", "Libanon", "Libéria", "Líbia", "Liechtenstein",
        "Litvánia", "Luxemburg", "Macedónia", "Madagaszkár", "Magyarország", "Makaó", "Malajzia", "Malawi",
        "Maldív-szigetek", "Mali", "Málta", "Marokkó", "Marshall-szigetek", "Martinique", "Mauritánia", "Mauritius",
        "Mayotte", "Mexikó", "Mianmar", "Mikronézia", "Moldova", "Monaco", "Mongólia", "Montenegró", "Montserrat",
        "Mozambik", "Namíbia", "Nauru", "Németország", "Nepál", "Nicaragua", "Niger", "Nigéria", "Niue",
        "Norfolk-sziget", "Norvégia", "Nyugat-Szahara", "Olaszország", "Omán", "Oroszország", "Örményország",
        "Pakisztán", "Palau", "Panama", "Pápua", "Új-Guinea", "Paraguay", "Peru", "Pitcairn-szigetek", "Portugália",
        "Puerto Rico", "Réunion", "Románia", "Ruanda", "Saint Kitts és Nevis", "Saint Lucia",
        "Saint-Pierre és Miquelon", "Saint Vincent és Grenadine-szigetek", "Salamon-szigetek", "Salvador", "San Marino",
        "São Tomé és Príncipe", "Seychelle-szigetek", "Sierra Leone", "Spanyolország", "Srí Lanka", "Suriname", "Svájc",
        "Svalbard szigetek", "Svédország", "Szamoa", "Szaúdi-Arábia", "Szenegál", "Szent Ilona", "Szerbia", "Szingapúr",
        "Szíria", "Szlovákia", "Szlovénia", "Szomália", "Szudán", "Szváziföld", "Tádzsikisztán", "Tajvan", "Tanzánia",
        "Thaiföld", "Togo", "Tokelau-szigetek", "Tonga", "Törökország", "Trinidad és Tobago", "Tunézia",
        "Turks- és Caicos-szigetek", "Tuvalu", "Türkmenisztán", "Uganda", "Új-Kaledónia", "Új-Zéland", "Ukrajna",
        "Uruguay", "Üzbegisztán", "Vanuatu", "Venezuela", "Vietnam", "Wallis és Futuna", "Zambia", "Zimbabwe",
        "Zöld-foki szigetek",)

    def county(self):
        return self.random_element(self.counties)

    def street_address_with_county(self):
        pattern = self.random_element(self.street_address_with_county_formats)
        return self.generator.parse(pattern)

    def city_prefix(self):
        return self.random_element(self.city_prefs)

    def city_part(self):
        return self.random_element(self.city_parts)

    def real_city_name(self):
        return self.random_element(self.real_city_names)

    def frequent_street_name(self):
        return self.random_element(self.frequent_street_names)

    def postcode(self):
        return "H-{}{}{}{}".format(super(Provider, self).random_digit_not_null(), super(Provider, self).random_digit(),
                                   super(Provider, self).random_digit(),
                                   super(Provider, self).random_digit())

    def street_name(self):
        return super(Provider, self).street_name().title()

    def building_number(self):
        numeric_part = super(Provider, self).random_int(1, 250)
        return str(numeric_part) + "."



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    first_names_female = (
        'Авгия', 'Авигея', 'Авторка', 'Аглая', 'Аглоида', 'Агнешка', 'Адамина', 'Адра', 'Адрианиа', 'Аела', 'Айрен', 'Аксентия', 'Алания',
        'Албина', 'Александрина', 'Алексиа', 'Аленка', 'Алиана', 'Алисия', 'Алтая', 'Амбър', 'Амория', 'АнаМария', 'Анатолия', 'Ангелка',
        'Андика', 'Андриана', 'Анелина', 'анета', 'Анза', 'Анимира', 'Аница', 'Аномалия', 'Антоалина', 'Антонела', 'Ануша', 'Анхея-мей',
        'Аполинария', 'Аралия', 'Аркадия', 'Арсена', 'Аселина', 'Асифа', 'Астромерия', 'Атина', 'Аурора', 'Багра', 'Балина', 'Бацислава',
        'Беатрис', 'Бела', 'Белисима', 'Беломира', 'Бенелена', 'Берислава', 'Бея', 'Билена', 'Бисера', 'Биянка', 'Благодатка', 'Благосвета',
        'Богдалина', 'Богородка', 'Бодурка', 'Божидара-силвестра', 'Божинела', 'Божурка', 'Бонифация', 'Борена', 'Бориска', 'Борянка', 'Боца', 'Бригита',
        'Бронислава', 'Буна', 'Буча', 'Бързана', 'Ваклина', 'Валерия', 'Валя', 'Вангелия', 'Ванухи', 'Варта', 'Васенка', 'Василина',
        'Васка', 'Вашиля', 'Вежда', 'Велиана', 'Велинна', 'Велиянка', 'Венда', 'Венеция', 'Венислава', 'Венчислава', 'Верена', 'Верислава',
        'Веса', 'Веселинка', 'Весна', 'Веца', 'Видима', 'Виктория', 'Вилия', 'Вилхема', 'Виолета', 'Виржиния', 'Витомира', 'Вишка',
        'Владилена', 'Владлена', 'Водица', 'Войнка', 'Вула', 'Възкресения', 'Въльо', 'Върбунка', 'Въца', 'Габи', 'Галена', 'Галина',
        'Галя', 'Гануца', 'Гвоздейка', 'Гена', 'Георгелена', 'Георгица', 'Герга', 'Гердана', 'Гертруда', 'Гиздана', 'Гичка', 'Гордана',
        'Гория', 'Гоца', 'Графица', 'Грета', 'Гримяна', 'Гроздинка', 'Гуна', 'Гъда', 'Гълъбица', 'Гюгра', 'Гюргя', 'Дакота', 'Дамяна',
        'Данелина', 'Данимира', 'Данка', 'Дарданела', 'Дария', 'Дафинка', 'Деа', 'Деви', 'Делиана', 'Деля', 'Демирела', 'Дениандра',
        'Дениславена', 'Денница', 'Десимиляна', 'Десияна', 'Дефлорина', 'Дея', 'Джана', 'Джиневра', 'Джулия', 'Диана-Мария', 'Дида', 'Дилмана',
        'Димитра', 'Димка', 'Динна', 'Добрина', 'Дойка', 'Доменика', 'Доника', 'Дора-Анна', 'Дорина', 'Доста', 'Доча', 'Драгица',
        'Дренка', 'Дуда', 'Душка', 'Дюкяна', 'Евангелина', 'Евдокия', 'Евридика', 'Едита', 'Ел', 'Елдора', 'Еленица', 'Елеонета', 'Ели',
        'Елиз', 'Елина', 'Елиса', 'Елица', 'Елма', 'Елфида', 'Емануила', 'Емма', 'Еница', 'Ергана', 'Ермиля', 'Естела',
        'Ефимена', 'Ефросиния', 'Жаклин', 'Жанин', 'Жара', 'Жейна', 'Желязка', 'Женимира', 'Жива', 'Живомира', 'Жичка', 'Жорка',
        'Жулиана', 'Заека', 'Занка', 'Зафа', 'Захаринка', 'Звездемира', 'Здравелина', 'Здухостина', 'Зинаида', 'Златея', 'Златка', 'Златомира',
        'Зоичка', 'Зорка', 'Зузичка', 'Ивалена', 'ивамина', 'Иванеса', 'Иваничка', 'Ивелиана', 'Ивинка', 'Иглика', 'Изидора', 'Илеана',
        'Илианна', 'Илинда', 'Илка', 'Инан', 'Инеса', 'Ира', 'Ирин', 'Ирла', 'Исихия', 'Истилияна', 'Йоана', 'Йоанна',
        'Йованка', 'Йоко', 'Йолина', 'Йона', 'Йоника', 'Йорданка', 'Йоханна', 'Кадифейка', 'Калея', 'Калина', 'Калиса', 'Калуда',
        'Камея', 'Кануша', 'Карамелита', 'Карина', 'Касиди', 'Катастрофа', 'Катинка', 'Каунка', 'Кветослава', 'Керанка', 'Кети', 'Кино',
        'Кирка', 'Китчица', 'Клара', 'Клеуна', 'Клоя', 'Кокимира', 'Комара', 'Константина', 'Корнелия', 'Костадинка', 'Кралина', 'Красидара',
        'Красияна', 'Криси', 'кристабела', 'Кристиана', 'Кристия', 'Кръстанка', 'Ксандриния', 'Кунка', 'Кьнина', 'Лада', 'Лазура', 'Лалка',
        'Лариса', 'Лаца', 'Лека', 'Ленче', 'Летисия', 'Либерта', 'Лидийка', 'Лика', 'Лилия', 'Лилянка', 'Линда', 'Лия',
        'Лозанка', 'Лорена', 'Лоти', 'Луна', 'Лъчезарка', 'Любина', 'Люблина', 'Любослава', 'Люляна', 'Люсила', 'Лянка', 'Магдалена',
        'Мадлен', 'Майя', 'Максимилияна', 'Малена', 'Малтина', 'Манолина', 'Мара-антоанета', 'Маргит', 'Марен', 'Мари-анри', 'Марийка', 'Маринета',
        'Мариотка', 'Мария', 'Мария-елена', 'Мария-Хуана', 'Марлена', 'Маруся', 'Маса', 'Матка', 'Маша', 'Медиха', 'Мелания', 'Мелъди',
        'Меропа', 'Миглена', 'Мила', 'Милара', 'милдия', 'Милиана', 'Милост', 'Мимоза', 'Минка', 'Миранза', 'Мирена', 'Миропа',
        'Мисла', 'Митошка', 'Михайлена', 'Мишка', 'Младлена', 'Момера', 'Моника', 'Мортадела', 'Мушана', 'Наводненка', 'Надка', 'Найда',
        'Нани', 'Настия', 'Наташа', 'Невена', 'Негрита', 'Неделяна', 'Нейка', 'Нелида', 'Нелла', 'Неолина', 'Нешка', 'Нигрита',
        'Никоела', 'Николина', 'Нионила', 'Нона', 'Норка', 'Нурета', 'Огнена', 'Октавия', 'Оливера', 'Омана', 'Орлеана', 'Орхидея',
        'Павилия', 'Павлина', 'Палвира', 'Паломина', 'Панда', 'Пантера', 'Парашкевица', 'Парунка', 'Патриотка', 'Паулина', 'Паца', 'Пейолина', 'Пелина',
        'Пепелота', 'Периана', 'перуна', 'Петинка', 'Петрийка', 'Петромира', 'Петрушка', 'Пешка', 'Пламена', 'Плодовитка', 'Полексина', 'Полин',
        'Правда', 'Преса', 'Прина', 'Пролетина', 'Простисвета', 'Пупи', 'Първолетка', 'Рада', 'Радиа', 'Радимира', 'Радка', 'Радосвета',
        'Радостка', 'Раинка', 'Райничка', 'Рамина', 'Ревка', 'Ренгия', 'Риана', 'Римма', 'Рия', 'Роза', 'Розана', 'Розета',
        'Розка', 'Роксана', 'Ромолета', 'Роселина', 'Росислава', 'Ростислава', 'Ружка', 'Румислава', 'Русалия', 'Руска', 'Сабина', 'Савета',
        'Салина', 'Санка', 'Сарая', 'Сахория', 'Свежа', 'Светла', 'Светломира', 'Свидна', 'Свободка', 'Севда', 'севделина', 'Севета',
        'Семенарка', 'Сергелинка', 'Сибила', 'Сиена', 'Силви', 'Силвия-александра', 'Силяна', 'Симона', 'Синтия', 'Сисоя', 'Скакалка', 'Славея',
        'Славка', 'Сладоледка', 'Смехотерапия', 'Смирна', 'Снежинка', 'Софийка', 'Спасена', 'Спасияна', 'Спирела', 'Стависара', 'Стаматка', 'Станиела',
        'Станимирка', 'Сташа', 'Стелина', 'Стефани', 'Стеяна', 'Стоимена', 'Столетка', 'Стоянка', 'Сузи', 'Съвестина', 'Сърменка', 'Таисия',
        'тамара', 'Таня', 'Ташимира', 'Теа', 'Телефонка', 'Темира', 'Теодора', 'Теса', 'Тилиана', 'Тиха', 'Тоанета', 'Толиана',
        'Тона', 'Тоницвета', 'Тоска', 'Тошка', 'Трендафила', 'Трифонка', 'Троша', 'Труфана', 'Тръпка', 'Туфка', 'Улиана', 'Урима',
        'Фабияна', 'Фатиме', 'Феня', 'Фикия', 'Филипини', 'Фимка', 'Флавия', 'Флорика', 'Фотинка', 'Фронка', 'Фуга', 'Хана',
        'Харитония', 'Хенриета', 'Хинка', 'Холи', 'Хранислава', 'Хрисанка', 'Христа', 'Христела', 'Христилияна', 'Христоелена', 'Христя', 'Хубавелка',
        'Цанета', 'Царевна', 'Цветана', 'Цветелина', 'Цветилена', 'Цветлина', 'Цветолилия', 'Цветяна', 'Цеца', 'Цола', 'Цоня', 'Чана',
        'Чардафона', 'Чачия', 'Череша', 'Четвърта', 'Чона', 'Чубрина', 'Шана', 'Шена', 'Шехерезада', 'Шинка', 'Щедра', 'Щериана',
        'Щефания', 'Щилянка', 'Щтилка', 'Ъгленка', 'Ъчка', 'Юлиена', 'Юлия', 'Юнона', 'Юрита', 'Юстианна', 'Ябленка', 'Явора', 'Ягода',
        'Ялислава', 'Яна-Мартина', 'Янина', 'Яниславия', 'Янка', 'Ярка', 'Ясена', 'Ятана'
    )

    first_names_male = (
        'Аблен', 'Август', 'Августиан', 'Августин', 'Авел', 'Авер', 'Аверно', 'Авксентий', 'Аво',
        'Аврам', 'Аврели', 'Аврелий', 'Аврор', 'Агапи', 'Агапий', 'Агатопод', 'Агент', 'Аглай',
        'Агнен', 'Агнеш', 'Агоп', 'Агъци', 'Адалберт', 'Адам', 'Адеан', 'Аделин', 'Адем',
        'Адриан', 'Адриян', 'Аерозол', 'Азалия', 'Айдемир', 'Акашия', 'Аксакусти', 'Аксидан', 'Аксинтия',
        'Алберт', 'Албияна', 'Алдин', 'Алевандър', 'Алег', 'Алек', 'Алекзандриян', 'Беримир', 'Берин',
        'Берия', 'Беро', 'Берослав', 'Бетина', 'Бетино', 'Бечо', 'Билян', 'Бинко', 'Биньо',
        'Бисенти', 'Бисер', 'Благо', 'Благовест', 'Благой', 'Благомир', 'Благосвет', 'Блаже', 'Бог',
        'Богиня', 'Богой', 'Боголюб', 'Богомил', 'Богослав', 'Бодромир', 'Божан', 'Божидар', 'Божик',
        'Божимир', 'Божин', 'Божинел', 'Божко', 'Божо', 'Божур', 'Боил', 'Боила', 'Бойко',
        'Бойчо', 'Болен', 'Болеслав', 'Боне', 'Бонислав', 'Бонко', 'Боно', 'Веселин', 'Весислав',
        'Весо', 'Веспасиян', 'Ветко', 'Вечко', 'Вигалот', 'Виго', 'Виделин', 'Виден', 'Видин',
        'Видослав', 'Видю', 'Викенти', 'Виктор', 'Вилиан', 'Вилизар', 'Вилизара', 'Вилислав', 'Вилиян',
        'Винету', 'Винко', 'Вино', 'Винсънт', 'Винченцо', 'Виолет', 'Виолин', 'Висарион', 'Виталий',
        'Витко', 'Витлян', 'Витомир', 'Витош', 'Вихрен', 'Вихрони', 'Вихър', 'Вичо', 'Виша',
        'Вишетин', 'Вишню', 'Влад', 'Владилен', 'Владимер', 'Владимир', 'Галентин', 'Галиен', 'Галимир',
        'Галиян', 'Гани', 'Ганислав', 'Ганцомир', 'Ганчо', 'Ганьо', 'Гаро', 'Гатьо', 'Гацо',
        'Гвардиана', 'Гелемир', 'Генади', 'ГенадиВалериев', 'Генадий', 'Генислав', 'Генко', 'Гено', 'Генчо',
        'Гео', 'Геодим', 'Геомил', 'Георги', 'Герасим', 'Герган', 'Гергей', 'Гергелюб', 'Гергин',
        'Гердан', 'Герман', 'Геро', 'Герой', 'Герчо', 'Гетислав', 'Гетко', 'Гето', 'Гецо',
        'Гечо', 'Гешо', 'Гивеза', 'Гиздален', 'Гико', 'Гилдрой', 'Делчо', 'Делян', 'Деляна',
        'Демир', 'Демян', 'Дениз', 'Деника', 'Денимир', 'Денис', 'Денислав', 'Дениян', 'Денчо',
        'Дердидас', 'десилиан', 'Десимир', 'Десислав', 'Деслав', 'Деспин', 'Деспинка', 'Деспот', 'Детелин',
        'Дечко', 'Дечо', 'Дечю', 'Дешо', 'Деян', 'Джанер', 'Джанко', 'Джихад', 'Джон-стефан',
        'Диаманди', 'Диамантина', 'Диан', 'Диван(надядоДианидядоИван)', 'Дивизие', 'Дивизия', 'Дивил', 'Дидко', 'Диего',
        'Дико', 'Дилян', 'Евстати', 'Евстатий', 'Евстахий', 'Евтим', 'Егор', 'Едвин', 'Едит',
        'Едрю', 'Едуард', 'Еким', 'Ектар', 'Ектор', 'Елвис', 'Елеан', 'Електрон', 'Елемаг',
        'Еленко', 'Елиан', 'Елиас', 'Елиезер', 'Елизабет', 'Елин', 'Елисей', 'Елисия', 'Елко',
        'Ельо', 'Ема-Бела', 'Еманоил', 'Емануел', 'Емануил', 'Емил', 'Емилиан', 'Емилиян', 'Ендо',
        'Енчо', 'Еньо', 'Еню', 'Ервин', 'Ередин', 'Еремия', 'Ерик', 'Ерина', 'Ерол',
        'Ерсен', 'Есен', 'Етиен', 'Ефка', 'Заварин', 'Завен', 'Замфир', 'Занго', 'Занко',
        'Запрян', 'Зарко', 'Зафер', 'Зафир', 'Захар', 'Захари', 'Захарин', 'Захо', 'Звездан',
        'Звездин', 'Звездислав', 'Звездиян', 'Звездолет', 'Звездомир', 'Згура', 'Здравелин', 'Здравец', 'Здравко',
        'Здравчо', 'Зенгин', 'Зика', 'Зинко', 'Зинови', 'Златан', 'Злати', 'Златил', 'Златимир',
        'Златиян', 'Златко', 'Златогор', 'Златозар', 'Златомир', 'Златослав', 'Златоцвет', 'Златьо', 'Золтан',
        'Илиомар', 'Илич', 'Илия', 'Илиян', 'Илко', 'Илчо', 'Имилиан', 'Ингемунд', 'Инко',
        'Инчо', 'Иполит', 'Ириан', 'Ириней', 'иринеус', 'Ириян', 'Ирко', 'Ирма', 'Ирник',
        'Исак', 'Исидор', 'Искрен', 'Искър', 'Исперих', 'Истан', 'Истатко', 'Истилян', 'Исус',
        'Итко', 'Ихтиандър', 'Ицо', 'Ичо', 'Йено', 'Йеремия', 'Йоан', 'Йоан-Александър', 'Йоан-иво',
        'Йован', 'Йовица', 'Йовко', 'Йово', 'Йовро', 'Йовцо', 'Йовчо', 'Йожи', 'Йоил',
        'Йолиян', 'Йолко', 'Карен', 'Карим', 'Карин', 'Карло', 'Кармен', 'Каролин', 'Карчо',
        'Катакомб', 'Каталинка', 'Катерин', 'Кевин', 'Кеворк', 'Кери', 'Кибер', 'Кимба', 'Кимбо',
        'Кимон', 'Кимчо', 'Кин', 'Кинка', 'Кинта', 'Киприслав', 'Киприян', 'Кириен', 'Кирил',
        'Кирчо', 'Киряк', 'Киряки', 'Киряко', 'Кис', 'Кит', 'Кито', 'Китодар', 'Китомир',
        'Клим', 'Климент', 'Кнут', 'Козма', 'Койно', 'Койо', 'Койчо', 'Коко', 'Коле',
        'Колчо', 'Кольо', 'Колю', 'Комнин', 'Лалко', 'Лало', 'Лальо', 'Ламби', 'Ламбо',
        'Ламбю', 'Ланселот', 'Ласкал', 'Ласкар', 'Ластър', 'Латин', 'Латко', 'Латьо', 'Латю',
        'ЛЕА-МАРИЯ', 'Леандър', 'Лев', 'Левент', 'Левчо', 'Леко', 'Ленин', 'Ленко', 'Леон',
        'Леонид', 'Лесе', 'Лефтер', 'Лечо', 'Лилко', 'Лило', 'Лилчо', 'Лилян', 'Лимон',
        'Липе', 'Лихия', 'Личо', 'Ловчо', 'Лозан', 'Лозана', 'Лозен', 'Лора-софия', 'Лоранс',
        'Лука', 'Лукан', 'Луко', 'Лули', 'Лулчо', 'Лусио', 'Лусия', 'Маноел', 'Манол',
        'Маноло', 'Мантас', 'Мануил', 'Мануш', 'МанчестърЮнайтед', 'Манчо', 'Маньо', 'Маню', 'Марангони',
        'Маргарит', 'Марек', 'Мариан', 'Марий', 'Марин', 'Маринел', 'Маринчо', 'Марио', 'Мариоллита',
        'Маритна', 'Мариян', 'Марк', 'Марк-антоний', 'Марко', 'Маркус', 'Мартен', 'Мартин', 'Мартиниян',
        'Маруш', 'Марчело', 'Маслина', 'Матей', 'Матьо', 'Матю', 'Махно', 'Машо', 'Медиан',
        'Мено', 'Мерилин', 'Месак', 'Метакса', 'Найо', 'Найчо', 'Наке', 'Нако', 'Нанко',
        'Нано', 'Нансимир', 'Нанчо', 'Наню', 'Нарцислав', 'Наско', 'Настимир', 'Настрадин', 'Натанаил',
        'Натко', 'Наум', 'Нафисат', 'Нафтали', 'Нацко', 'Нацо', 'Начиян', 'Начко', 'Начо',
        'Невен', 'Невенко', 'Невилиян', 'Невян', 'Негослав', 'Неделин', 'Неделчо', 'Недислав', 'Недко',
        'Недьо', 'Недю', 'Недялко', 'Нейко', 'Нейчо', 'Нелко', 'Нелчо', 'Нене', 'Ненко',
        'Ненсислав', 'Ненчо', 'Неокли', 'Нерес', 'Обретим', 'Ованес', 'Огин', 'Огнемир', 'Огнен',
        'Океан', 'Олег', 'Олек', 'Олимпи', 'Омар', 'Омуртаг', 'Оник', 'Онуфри', 'Ончо',
        'Орлин', 'Ортодокси', 'Орфей', 'Орхидей', 'Орце', 'Оскар', 'Оханес', 'Павел', 'Павелин',
        'Павко', 'Павлик', 'Павлин', 'Павлинчо', 'Павломир', 'Паисий', 'Пако', 'Палми', 'Палмиро',
        'Панай', 'Панайот', 'Панде', 'Панделис', 'Пане', 'Панкртийян', 'Пано', 'Панталей', 'Пантелей',
        'Панто', 'Пантю', 'Панчо', 'Паолина', 'Параскев', 'Параход', 'Парашкев', 'Парашкеван', 'Паруш',
        'Паско', 'Паспанахил', 'Пато', 'Патрик', 'Патьо', 'Паулин', 'Паун', 'Пацо', 'Пачо',
        'Пейко', 'Пейо', 'Пейодон', 'Пейтан', 'Пейчин', 'Пейчо', 'Пеко', 'Пелай', 'Пеле',
        'Пенко', 'Пенчин', 'Пенчо', 'Пеньо', 'Пеню', 'Пео', 'Пепино', 'Пепислав', 'Пепо',
        'Перикъл', 'Персиана', 'Персиян', 'Перчо', 'Петиконгрес', 'Петкан', 'Петко', 'Пето', 'Петраки',
        'Петрана', 'Петринел', 'Петрозар', 'Петромил', 'Рангел', 'Рангел-любими', 'Рандю', 'Ранчо', 'Расате',
        'Рафаил', 'Рачко', 'Рачо', 'Рашко', 'Рашо', 'Раю', 'Раян', 'Реан', 'Рем',
        'Риналдо', 'Рис', 'Ристя', 'Ричард', 'Ричерд', 'Роберт', 'Роберто', 'Робин', 'Робърт',
        'Рогелина', 'Рогена', 'Родан', 'Родион', 'Розалин', 'Розин', 'Розоцвет', 'Ройо', 'Роксан',
        'Ромел', 'Ромелина', 'Ромен', 'Ромео', 'Ромил', 'Ромул', 'Росен', 'Росенка', 'Росимир',
        'Роска', 'Роско', 'Ростиана', 'Ростимир', 'Ростислав', 'Светломир', 'Светлю', 'Светозар', 'Светослав',
        'Себастиан', 'Себахтин', 'Севан', 'Севар', 'Севастин', 'Севдалин', 'Севдан', 'Севелин', 'Северин',
        'Седеф', 'Седефчо', 'Селен', 'Селена', 'Сенко', 'Серафим', 'Сергей', 'Сеслав', 'Сиви',
        'Сидер', 'Сидония', 'Сидор', 'Сиен', 'Силаги', 'Силан', 'Силвестър', 'Силвио', 'Силвиян',
        'Силян', 'Симеон', 'Симо', 'Сирман', 'Сифоня', 'Скорбут', 'Слав', 'Славдо', 'Славе',
        'Славейко', 'Славен', 'Слави', 'Славил', 'Теодоси', 'Теодосий', 'Теодослав', 'Теодостин', 'Теофан',
        'Теохар', 'Тервел', 'Тигрони', 'Тило', 'Тильо', 'Тимо', 'Тимон', 'Тимотей', 'Тимчо',
        'Тино', 'Тинчо', 'Тихо', 'Тихол', 'Тихомир', 'Тихон', 'Тишо', 'Тоде', 'Тодомирка',
        'Тодораки', 'Тодорин', 'Тодорина', 'Токимир', 'Толек', 'Толю', 'Тома', 'Томас', 'Томен',
        'Томинка', 'Томислав', 'Томо', 'Тоне', 'Тони', 'Тонимир', 'Тонислав', 'Тонко', 'Тончо',
        'Топалко', 'Тополко', 'Тотко', 'Тотьо', 'Тотю', 'Тоцо', 'Филатей', 'Фили', 'Филидан',
        'Филион', 'Филип', 'Филипас', 'Филипопол', 'Филко', 'Филомир', 'Филчо', 'Фильо', 'Финдо',
        'Фиро', 'Фирчо', 'Фичо', 'Флори', 'Флориан', 'Флорин', 'Флоро', 'Фори', 'Фосил',
        'Франк', 'Франц', 'Францислав', 'Фрацил', 'Фреди', 'Фродо', 'Фуго', 'Фуко', 'Фъстък',
        'Фьодор', 'Хавтелин', 'Ханко', 'Хараламби', 'Харалампи', 'Харалан', 'Харбингър', 'Хари', 'Харизан',
        'Харитон', 'Хасан', 'Хасатин', 'Хачо', 'Хвойне', 'Хебър', 'Хектор', 'Хераклит', 'Хернани',
        'Хефестион', 'Химинай', 'Хинко', 'Хино', 'Хитко', 'Хороз', 'Храбрин', 'Храбър', 'Хранимир',
        'Хрелко', 'Хрельо', 'Хрисим', 'Хрисимир', 'Хрисо', 'Христалин', 'Христивилин', 'Христиела', 'Христилиан',
        'християн', 'Христо', 'Христо-никола', 'Христодор', 'Христозар', 'Христозорнициан', 'Христозорницомил', 'Христомил', 'Христомир',
        'Христослав', 'Христофор', 'Хрисчо', 'Хрондел', 'Хрусан', 'Хубав', 'Хубавен', 'Хубан', 'Хубен',
        'Цоню', 'Цоцо', 'Цочо', 'Цъки', 'Чавдар', 'Чанкете', 'Чанко', 'Чано', 'Чаньо',
        'Чардафон', 'Чародей', 'Чауш', 'Чачо', 'Чвор', 'Чедомир', 'Ченко', 'Ченю', 'Чепо',
        'Черноризец', 'Черньо', 'Чийо', 'Чико', 'Чило', 'Чонар', 'Чони', 'Чоно', 'Чоню',
        'Чочо', 'Чочомир', 'Чубрик', 'Чуде', 'Чудо', 'Чудомир', 'Чудослав', 'Чук', 'Шабан',
        'Шанко', 'Шаноу', 'Шаро', 'Шейна', 'Шеки', 'Шенко', 'Шенол', 'Шибил', 'Шидер',
        'Шинко', 'Шино', 'Шипчан', 'Ширко', 'Шишман', 'Шкодри', 'Шмильо', 'Шмулю', 'Шпилко',
        'Шушо', 'Щедрин', 'Щедю', 'Щеки', 'Щено', 'Щеню', 'Щерион', 'Щериян', 'Щерко',
        'Щерьо', 'Щерю', 'Щилиян', 'Щилян', 'Щирян', 'Щоно', 'Щтърбан', 'Щтъркан', 'Щурк',
        'Щърбан', 'Щъркан', 'Ъглен', 'Ълен', 'Ърнест', 'Ъруин', 'Ърчо', 'Ьобирдар', 'Юги',
        'Юлиан', 'Юлий', 'Юлиян', 'Юрдан', 'Юри', 'Юрий', 'Юстин', 'Юстиниан', 'Яблен',
        'Явор', 'Яго', 'Ягодин', 'Язо', 'Яким', 'Яко', 'Якоб', 'Яков', 'Якослав',
        'Ян', 'Янадин', 'Янаки', 'Янакин', 'Яначко', 'Яне', 'Янег', 'Янедин', 'Янек',
        'Яни', 'Яниел', 'Яник', 'Янимир', 'Янис', 'Янислав', 'Яничко', 'Янко', 'Янкул',
        'Яно', 'Яномил', 'Янтар', 'Януш', 'Янцислав', 'Янче', 'Янчо', 'Ярно', 'Яромир',
        'Ярце', 'Ярчо', 'Яръм', 'Ярю', 'Ясен', 'Ясер', 'Ястреб', 'Ятан', 'Яцо',
        'Ячо', 'Яшар', 'Яшка', 'Яшо', 'Яшон'
    )

    last_names_male = (
        'Симеонов', 'Данданов', 'Кърков', 'Братухчев', 'Цветков', 'Иванов', 'Яназов', 'Тодоров', 'Колчев',
        'Келешев', 'Бърборков', 'Дришльов', 'Макаронски', 'Количков', 'Принов', 'Бодуров', 'Китов', 'Гьоков',
        'Симеонов', 'Балахуров', 'Милачков', 'ЕвроповКирилов', 'Площаков', 'Мангъров', 'Хвърчилков', 'Дзезов', 'Ждраков',
        'Тухчиев', 'Топков', 'Яков', 'Иликьов', 'Бурханларски', 'Вражалски', 'Тутурилов', 'Бранков', 'Зенгинов',
        'Фенеров', 'Кучев', 'Възвъзов', 'Кьоров', 'Джогов', 'Пъков', 'Рангелов', 'Чутурков', 'Самсонов',
        'Андонов', 'Бумов', 'Мочев', 'Дачев', 'Муев', 'Младенов', 'Тошев', 'Бедринов', 'Тумангелов',
        'Канчин', 'Миленков', 'Патков', 'Пондьов', 'Самоходов', 'Четрафилски', 'Смърдански', 'Клатуров', 'Вакрилов',
        'Прошков', 'Пулев', 'Парашкевов', 'Манавски', 'Чуков', 'Овнарски', 'Рошльов', 'Пройкова', 'Младенова',
        'Кесьов', 'Римпопов', 'Златков', 'Колев', 'Пикянски', 'Николов', 'Цицков', 'Стойков', 'Каракашев',
        'Докова', 'Мераков', 'Пеева', 'Педалов', 'Тъпчилещов', 'Въртунински', 'Кодуков', 'Татьозов', 'Токов',
        'Юрганчев', 'Клатикрушев', 'Монтянов', 'Бобев', 'Топчийски', 'Луланков', 'Костов', 'Колипатков', 'Чукчуков',
        'Катъров', 'Кобиларов', 'Лимонадов', 'Цоцов', 'Поаков', 'Недялков', 'Станишев', 'Йорданов', 'Щърбов',
        'Занов'
    )

    last_names_female = (
        'Кокошкова', 'Градинарова', 'Куртакова', 'Чанлиева', 'Тодорова', 'Пътечкова', 'Скринска', 'Сапунджиева', 'Вампирска',
        'Васовa', 'Таралингова', 'Илиева', 'Кривошапкова', 'Чупетловска', 'Катърова', 'Бележкова', 'Мустакова', 'Пръндачка',
        'Йоткова', 'Сланинкова', 'Мангъфова', 'Шкембова', 'Пенджакова', 'Пачаръзка', 'Куртажова', 'Плюнкова', 'Многознаева',
        'Белоконска-Вражалска', 'Кучкуделова', 'Крушовска', 'Пищовколева', 'Сопаджиева', 'Точева-Клопова', 'Габровлиева', 'Първанова', 'Певецова',
        'Яркова', 'Плюцова', 'Балканска'
    )

    prefixes_female = ('Г-жа', 'Г-ца', 'Др.')
    prefixes_male = ('Г-н', 'Др.')

    formats_female = (
        '{{first_name_female}} {{last_name_female}}',
        '{{prefix_female}} {{first_name_female}} {{last_name_female}}',
    )

    formats_male = (
        '{{first_name_male}} {{last_name_male}}',
        '{{prefix_female}} {{first_name_male}} {{last_name_male}}'
    )

    formats = formats_male + formats_female
    first_names = first_names_male + first_names_female
    last_names = last_names_male + last_names_female



# coding=utf-8

from __future__ import unicode_literals
from ..es import Provider as AddressProvider


class Provider(AddressProvider):
    building_number_formats = ('%', '%#', '%#', '%#', '%##')
    street_prefixes = (
        'Plaza', 'Calle', 'Avenida', 'Via', 'Vial', 'Rambla', 'Glorieta',
        'Urbanización', 'Callejón', 'Cañada', 'Alameda', 'Acceso', 'C.',
        'Ronda', 'Pasaje', 'Cuesta', 'Pasadizo', 'Paseo', 'Camino',
    )
    postcode_formats = ('#####', )
    states = (
        'Álava', 'Albacete', 'Alicante', 'Almería', 'Asturias', 'Ávila', 'Badajoz',
        'Baleares', 'Barcelona', 'Burgos', 'Cáceres', 'Cádiz', 'Cantabria', 'Castellón',
        'Ceuta', 'Ciudad', 'Córdoba', 'Cuenca', 'Girona', 'Granada', 'Guadalajara',
        'Guipúzcoa', 'Huelva', 'Huesca', 'Jaén', 'La Coruña', 'La Rioja', 'Las Palmas',
        'León', 'Lleida', 'Lugo', 'Madrid', 'Málaga', 'Melilla', 'Murcia', 'Navarra',
        'Ourense', 'Palencia', 'Pontevedra', 'Salamanca', 'Santa Cruz de Tenerife',
        'Segovia', 'Sevilla', 'Soria', 'Tarragona', 'Teruel', 'Toledo', 'Valencia',
        'Valladolid', 'Vizcaya', 'Zamora', 'Zaragoza'
    )

    city_formats = (
        '{{state_name}}',
    )

    street_name_formats = (
        '{{street_prefix}} {{first_name}} {{last_name}}',
        '{{street_prefix}} de {{first_name}} {{last_name}}',

    )
    street_address_formats = (
        '{{street_name}} {{building_number}}',
        '{{street_name}} {{building_number}} {{secondary_address}} ',
    )
    address_formats = (
        "{{street_address}}\n{{city}}, {{postcode}}",
    )
    secondary_address_formats = ('Apt. ##', 'Piso #', 'Puerta #')

    def state_name(self):
        return self.random_element(self.states)

    def street_prefix(self):
        return self.random_element(self.street_prefixes)

    def secondary_address(self):
        return self.numerify(self.random_element(self.secondary_address_formats))

    def state(self):
        return self.random_element(self.states)



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider

# Russian jobs taken from the Wikipedia page
# https://ru.wikipedia.org/wiki/%D0%A1%D0%BF%D0%B8%D1%81%D0%BE%D0%BA_%D0%BF%D1%80%D0%BE%D1%84%D0%B5%D1%81%D1%81%D0%B8%D0%B9
class Provider(BaseProvider):
    jobs=["Авиадиспетчер",
"Авиатехник",
"Авиационный техник",
"Автогонщик",
"Автослесарь",
"Автоэлектрик",
"Агроном",
"Агроном по защите растений",
"Агроном-почвовед",
"Адвокат",
"Администратор базы данных",
"Аккумуляторщик",
"Актуарий",
"Актёр",
"Акушер",
"Аллерголог",
"Аналитик",
"Андролог",
"Антрополог",
"Артиллерист",
"Артист цирка",
"Археолог",
"Архивариус",
"Архитектор",
"Астроном",
"Астрофизик",
"Астрохимик",
"Бактериолог",
"Балерина",
"Балетмейстер",
"Банкир",
"Бармен",
"Баталер",
"Безработный",
"Библиотекарь",
"Библиотековед",
"Биоинженер",
"Биолог",
"Биофизик",
"Биохимик",
"Блоггер",
"Бондарь",
"Борт-инженер",
"Борт-механик",
"Борт-радист",
"Борт-стрелок",
"Бортинженер",
"Бортмеханик",
"Бортпроводник/стюард",
"Ботаник",
"Брейдер",
"Брокер",
"Булочник",
"Бульдозерист",
"Бухгалтер",
"Веб-интегратор",
"Веб-мастер",
"Веб-программист",
"Верстальщик",
"Ветеринар",
"Визажист",
"Виноградарь",
"Вирусолог",
"Водитель",
"Водолаз",
"Военно-полевой хирург",
"Военно-полевой хирург",
"Военнослужащий",
"Военный дознаватель",
"Военный консультант",
"Военный переводчик",
"Военный полицейский",
"Военный прокурор",
"Военный судья",
"Военный юрист",
"Воздухоплаватель",
"Вокалист",
"Воспитатель",
"Воспитатель",
"Востоковед",
"Врач МСЭК",
"Врач УЗ-диагностики",
"Врач скорой помощи",
"Врач функциональной диагностики",
"Выпускающий редактор",
"Гастроэнтеролог",
"Гематолог",
"Генетик",
"Генетик",
"Географ",
"Геодезист",
"Геолог",
"Гепатолог",
"Гидролог",
"Гинеколог",
"Гирудотерапевт",
"Гитарист",
"Гляциолог",
"Гомеопат",
"Горничная",
"Горнострелок",
"Горняк",
"Государственный исполнитель",
"Гранатомётчик",
"Грейдерист",
"Гренадер",
"Гример",
"Грузчик",
"Дворник",
"Декан",
"Декоратор",
"Дерматолог",
"Десантник",
"Детектив",
"Дефектолог",
"Диверсант",
"Диджей",
"Диетолог",
"Дизайнер",
"Дизайнер рекламы",
"Дизайнер-конструктор",
"Диктор",
"Дилер",
"Дипломат",
"Дипломат",
"Дипломатический работник",
"Дирижёр",
"Диспетчер",
"Дознаватель",
"Донкерман",
"Доула",
"Доярка",
"Драпировщик",
"Египтолог",
"Животновод",
"Жиловщик/Обвальщик",
"Журналист",
"Заряжающий",
"Заточник",
"Звукорежиссёр",
"Зенитчик",
"Златокузнец",
"Зоолог",
"Зоотехник",
"Издатель",
"Изобретатр",
"Иконописец",
"Иллюстратор",
"Имиджмейкер",
"Иммунолог",
"Инженер",
"Инженер",
"Инженер КИПиА",
"Инженер по Технике Безопасности",
"Инженер по механизации",
"Инженер-акустик",
"Инженер-взрывотехник",
"Инженер-гальваник",
"Инженер-гидравлик",
"Инженер-конструктор",
"Инженер-лаборант",
"Инженер-лесотехник",
"Инженер-механик",
"Инженер-системотехник",
"Инженер-строитель",
"Инженер-технолог",
"Инженер-физик",
"Инженер-химик",
"Инженер-электрик",
"Инженер-энергетик",
"Инкассатор",
"Интендант",
"Инфекционист",
"Искусствовед",
"Историк",
"Ихтиолог",
"Кабельщик",
"Кавалерист",
"Каменотёс",
"Канонир",
"Капитан судна",
"Каптенармус",
"Кардиолог",
"Кардиохирург",
"Каскадёр",
"Кассир",
"Квасник",
"Кинодраматург",
"Кинолог",
"Кинолог",
"Киномеханик",
"Кинооператор",
"Кинорежиссер",
"Кладовщик",
"Клинер",
"Кнопочник",
"Кодер",
"Кок",
"Командир",
"Комбайнер",
"Комендант",
"Коммерческий директор",
"Композитор",
"Конвоир",
"Кондитер",
"Кондитер",
"Кондуктор",
"Коневод",
"Контент-менеджер",
"Копирайтер",
"Корректировщик",
"Корректор",
"Косметолог",
"Космонавт",
"Крановщик",
"Кредитный консультант",
"Криптозоолог",
"Критик",
"Кровельщик",
"Кромкозакатчик",
"Крупье",
"Кузнец",
"Культуролог",
"Лаборант",
"Лекальщик",
"Лимфолог",
"Лингвист",
"Литейщик",
"Лифтёр",
"Логик",
"Логопед",
"Логопед",
"Лоцман",
"Лётчик",
"Лётчик",
"Маклер биржевой",
"Маляр",
"Маммолог",
"Манекенщица",
"Мануалист",
"Маркетолог",
"Маркитант",
"Маркшейдер",
"Массажист",
"Мастер маникюра",
"Мастер маникюра",
"Мастер педикюра",
"Математик",
"Машинист",
"Машинист локомотива",
"Машинистка",
"Медицинская сестра",
"Медник",
"Мелиоратор",
"Мельник",
"Менеджер",
"Менеджер по работе с клиентами",
"Мерчандайзер",
"Месильщик",
"Металлург",
"Метеоролог",
"Метранпаж",
"Метрдотель",
"Механизатор",
"Механик",
"Механик-Водитель",
"Миколог",
"Микробиолог",
"Министр",
"Модель",
"Модельер",
"Монтажник",
"Монтажник радиоэлектронной аппаратуры и приборов",
"Монтажник связи",
"Морской пехотинец",
"Моторист",
"Моторист",
"Мотострелок",
"Музыкант",
"Мусоропроводчик",
"Мусорщик",
"Мясник",
"Наводчик орудия",
"Налоговый инспектор",
"Нарколог",
"Начальник военного оркестра",
"Начальник гаупвахты",
"Начальник склада",
"Начальник службы",
"Начальник штаба",
"Невролог",
"Невропатолог",
"Нейрохирург",
"Неонатолог",
"Нефролог",
"Нотариус",
"Няня",
"Огнемётчик",
"Океанолог",
"Онколог",
"Оперативный работник",
"Оператор ПК",
"Оператор РЛС",
"Оператор вооружения",
"Оператор кино и телевидения",
"Оператор коллцентра",
"Оператор машинного доения",
"Операционист",
"Организатор свадеб",
"Орнитолог",
"Ортодонт",
"Ортопед",
"Особист",
"Оториноларинголог",
"Официант",
"Офтальмолог",
"Палеонтолог",
"Парикмахер",
"Парикмахер",
"Парфюмер",
"Пастух",
"Патологоанатом",
"Педагог",
"Педиатр",
"Пекарь",
"Переводчик",
"Переводчик",
"Переплётчик",
"Печатник",
"Писатель",
"Пластический хирург",
"Плиточник",
"Плотник",
"Повар",
"Повар",
"Пограничник",
"Подводник",
"Пожарный",
"Политолог",
"Полицейский",
"Портной",
"Портье",
"Постановщик трюков",
"Почтальон",
"Поэт",
"Правовед",
"Предприниматель",
"Преподаватель",
"Проводник",
"Программист",
"Программист",
"Продавец",
"Продавец",
"Продюсер",
"Прозектор",
"Проктолог",
"Прокурор",
"Промышленный альпинист",
"Промышленный альпинист",
"Проректор",
"Профпатолог",
"Проходчик",
"Психиатр",
"Психолог",
"Психоневропатолог",
"Психотерапевт",
"Пулемётчик",
"Пульмонолог",
"Пчеловод",
"Работник органов ЗАГСа",
"Радиолог",
"Радиомеханик",
"Радиотелефонист",
"Радист",
"Радист",
"Разведчик",
"Ракетчик",
"Распиловщик",
"Растениевод",
"Расточник",
"Реаниматолог",
"Ревматолог",
"Редактор",
"Режиссёр",
"Ректор",
"Релайтер",
"Религиовед",
"Рентгенолог",
"Реставратор",
"Рефлексотерапевт",
"Рихтовщик",
"Робототехник",
"Садовник",
"Садовод",
"Санитар",
"Сантехник",
"Сапожник",
"Сапёр",
"Сборщик",
"Сварщик",
"Связист",
"Священнослужитель",
"Секретчик",
"Сексолог",
"Сексопатолог",
"Семейный врач",
"Серпентолог",
"Сиделка",
"Системный администратор",
"Скорняк",
"Скотник",
"Скульптор",
"Следователь",
"Слесарь",
"Слесарь-механик",
"Сметчик",
"Снабженец",
"Снайпер",
"Сомелье",
"Сомнолог",
"Социолог",
"Специалист по клеточным технологиям",
"Специалист по стрижке овец",
"Спортивный врач",
"Сталевар",
"Старшина",
"Стилист",
"Столяр",
"Столяр-краснодеревщик",
"Стоматолог",
"Страховой агент",
"Стрелок",
"Стрелочник",
"Строитель",
"Судебный пристав",
"Судья",
"Сурдолог",
"Сурдопедагог",
"Сценарист",
"Сыровар",
"Табаковод",
"Табунщик",
"Таксист",
"Тальман",
"Таможенник",
"Танатолог",
"Танкист",
"Танцор",
"Татуировщик",
"Телеграфист",
"Тележурналист",
"Телемастер",
"Телефонист",
"Телохранитель",
"Теолог",
"Терапевт",
"Териолог",
"Тестировщик",
"Техник",
"Техник",
"Технолог",
"Типограф",
"Тифлопедагог",
"Товаровед",
"Токарь",
"Токарь-карусельщик",
"Токсиколог",
"Топограф",
"Торакальный хирург",
"Торговый представитель",
"Травматолог",
"Тракторист",
"Трансфузиолог",
"Трейдер",
"Тренд-вотчер",
"Тыловик",
"Тюремный надзиратель",
"Уборщик",
"Упаковщик",
"Уролог",
"Учитель",
"Учёный",
"Фальцовщик",
"Фармацевт",
"Фельдшер",
"Фельдшер",
"Фермер",
"Физик",
"Физиотерапевт",
"Филолог",
"Философ",
"Финансист",
"Финансист",
"Флеболог",
"Флорист",
"Флорист",
"Формовщик",
"Фортификатор",
"Фотограф",
"Фотомодель",
"Фрезеровщик",
"Фтизиатр",
"Фуражир",
"Футуролог",
"Химик",
"Химик",
"Химик-аналитик",
"Химик-контролер",
"Химик-технолог",
"Хирург",
"Хлебопёк",
"Хлебороб",
"Хлопокороб",
"Холодильщик",
"Хореограф",
"Художник",
"Художник по свету",
"Шахтёр",
"Швейцар",
"Швея",
"Шифровальщик",
"Шкипер",
"Шлифовщик",
"Шорник",
"Штукатур",
"Штурман",
"Эколог",
"Экономист",
"Экспедитор",
"Экспедитор на дальних поездках",
"Эксперт-криминалист",
"Электрик",
"Эндокринолог",
"Эндоскопист",
"Энтомолог",
"Эпидемиолог",
"Эфферентолог",
"Ювелир",
"Юрисконсульт",
"Юрист"]



# coding=utf-8

from __future__ import unicode_literals

import inspect

from .compat import getargspec

from faker import utils


class Documentor(object):

    def __init__(self, generator):
        """
        :param generator: a localized Generator with providers filled,
                          for which to write the documentation
        :type generator: faker.Generator()
        """
        self.generator = generator
        self.max_name_len = 0
        self.already_generated = []

    def get_formatters(self, locale=None, excludes=None, **kwargs):

        self.max_name_len = 0
        self.already_generated = [] if excludes is None else excludes[:]
        formatters = []
        providers = self.generator.get_providers()
        for provider in providers[::-1]:  # reverse
            if locale and provider.__lang__ != locale:
                continue
            formatters.append(
                (provider, self.get_provider_formatters(provider, **kwargs))
            )
        return formatters

    def get_provider_formatters(self, provider, prefix='fake.',
                                with_args=True, with_defaults=True):

        formatters = {}

        for name, method in inspect.getmembers(provider, inspect.ismethod):
            # skip 'private' method and inherited methods
            if name.startswith('_') or name in self.already_generated:
                continue

            arguments = []
            faker_args = []
            faker_kwargs = {}

            if name == 'binary':
                faker_kwargs['length'] = 1024

            if with_args:
                # retrieve all parameter
                argspec = getargspec(method)

                lst = [x for x in argspec.args if x not in ['self', 'cls']]
                for i, arg in enumerate(lst):

                    if argspec.defaults and with_defaults:

                        try:
                            default = argspec.defaults[i]
                            if utils.is_string(default):
                                default = utils.quote(default)
                            else:
                                # TODO check default type
                                default = "{0}".format(default)

                            arg = "{0}={1}".format(arg, default)

                        except IndexError:
                            pass

                    arguments.append(arg)
                    if with_args == 'first':
                        break

                if with_args != 'first':
                    if argspec.varargs:
                        arguments.append('*' + argspec.varargs)
                    if argspec.varkw:
                        arguments.append('**' + argspec.varkw)

            # build fake method signature
            signature = "{0}{1}({2})".format(prefix,
                                             name,
                                             ", ".join(arguments))

            # make a fake example
            example = self.generator.format(name, *faker_args, **faker_kwargs)

            formatters[signature] = example

            self.max_name_len = max(self.max_name_len, len(signature))
            self.already_generated.append(name)

        return formatters

    @staticmethod
    def get_provider_name(provider_class):
        return provider_class.__provider__



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    # https://en.wikipedia.org/wiki/Demographics_of_Estonia#Ethnic_groups
    # Main population groups in Estonia are Estonians and ethnic Russians:
    # About 70% of the population are Estonians and about 25% are Russians
    est_rat = 0.7
    rus_rat = 1.0 - est_rat
    formats = {'{{first_name_est}} {{last_name_est}}': est_rat,
               '{{first_name_rus}} {{last_name_rus}}': rus_rat}

    formats_male = {'{{first_name_male_est}} {{last_name_est}}': est_rat,
                    '{{first_name_male_rus}} {{last_name_rus}}': rus_rat}
    formats_female = {'{{first_name_female_est}} {{last_name_est}}': est_rat,
                      '{{first_name_female_rus}} {{last_name_rus}}': rus_rat}

    prefixes_neutral = ('doktor', 'dr', 'prof')
    prefixes_male = ('härra', 'hr') + prefixes_neutral
    prefixes_female = ('proua', 'pr') + prefixes_neutral
    prefixes = set(prefixes_male + prefixes_female)

    suffixes = ('PhD', 'MSc', 'BSc')

    # source: http://www.stat.ee/public/apps/nimed/TOP
    # TOP 50 male names in 2017 according to the Statistics Estonia
    first_names_male_est = ('Aivar', 'Aleksander', 'Alexander', 'Andres',
                            'Andrus', 'Ants', 'Indrek', 'Jaan', 'Jaanus',
                            'Jüri', 'Kristjan', 'Marek', 'Margus', 'Marko',
                            'Martin', 'Mati', 'Meelis', 'Mihkel',  'Peeter',
                            'Priit', 'Raivo', 'Rein', 'Sander', 'Siim', 'Tarmo',
                            'Tiit', 'Toomas', 'Tõnu', 'Urmas', 'Vello')

    first_names_female_est = ('Aino', 'Anna', 'Anne', 'Anneli', 'Anu', 'Diana',
                              'Ene', 'Eve', 'Kadri', 'Katrin', 'Kristi',
                              'Kristiina', 'Kristina', 'Laura', 'Linda', 'Maie',
                              'Malle', 'Mare', 'Maria', 'Marika', 'Merike',
                              'Niina', 'Piret', 'Reet', 'Riina', 'Sirje',
                              'Tiina', 'Tiiu', 'Triin', 'Ülle')

    first_names_est = first_names_male_est + first_names_female_est

    first_names_male_rus = ('Aleksander', 'Aleksandr', 'Aleksei', 'Alexander',
                            'Andrei', 'Artur', 'Dmitri', 'Igor', 'Ivan',
                            'Jevgeni', 'Juri', 'Maksim', 'Mihhail', 'Nikolai',
                            'Oleg', 'Pavel', 'Roman', 'Sergei', 'Sergey',
                            'Valeri', 'Viktor', 'Vladimir')

    first_names_female_rus = ('Aleksandra', 'Anna', 'Diana', 'Elena', 'Galina',
                              'Irina', 'Jekaterina', 'Jelena', 'Julia',
                              'Kristina', 'Ljubov', 'Ljudmila', 'Maria',
                              'Marina', 'Nadežda', 'Natalia', 'Natalja', 'Nina',
                              'Olga', 'Svetlana', 'Tamara', 'Tatiana',
                              'Tatjana', 'Valentina', 'Viktoria')

    first_names_rus = first_names_male_rus + first_names_female_rus

    first_names_male = set(first_names_male_est + first_names_male_rus)
    first_names_female = set(first_names_female_est + first_names_female_rus)
    first_names = first_names_male | first_names_female

    # http://ekspress.delfi.ee/kuum/\
    # top-500-eesti-koige-levinumad-perekonnanimed?id=27677149
    last_names_est = ('Aas', 'Aasa', 'Aasmäe', 'Aavik', 'Abel', 'Adamson',
                      'Ader', 'Alas', 'Allas', 'Allik', 'Anderson', 'Annus',
                      'Anton', 'Arro', 'Aru', 'Arula', 'Aun', 'Aus', 'Eller',
                      'Erik', 'Erm', 'Ernits', 'Gross', 'Hallik', 'Hansen',
                      'Hanson', 'Hein', 'Heinsalu', 'Heinsoo', 'Holm', 'Hunt',
                      'Härm', 'Ilves', 'Ivask','Jaakson', 'Jaanson', 'Jaanus',
                      'Jakobson', 'Jalakas', 'Johanson', 'Juhanson', 'Juhkam',
                      'Jänes', 'Järv', 'Järve', 'Jõe', 'Jõesaar', 'Jõgi',
                      'Jürgens', 'Jürgenson', 'Jürisson', 'Kaasik', 'Kadak',
                      'Kala', 'Kalamees', 'Kalda', 'Kaljula', 'Kaljurand',
                      'Kaljuste', 'Kaljuvee', 'Kallas', 'Kallaste', 'Kalm',
                      'Kalmus', 'Kangro', 'Kangur', 'Kapp', 'Karro', 'Karu',
                      'Kasak', 'Kase', 'Kasemaa', 'Kasemets', 'Kask', 'Kass',
                      'Kattai', 'Kaur', 'Kelder', 'Kesküla', 'Kiik', 'Kiil',
                      'Kiis', 'Kiisk', 'Kikas', 'Kikkas', 'Kilk', 'Kink',
                      'Kirs', 'Kirsipuu', 'Kirss', 'Kivi', 'Kivilo', 'Kivimäe',
                      'Kivistik', 'Klaas', 'Klein', 'Koger', 'Kohv', 'Koit',
                      'Koitla', 'Kokk', 'Kolk', 'Kont', 'Kool', 'Koort',
                      'Koppel', 'Korol', 'Kotkas', 'Kotov', 'Koval', 'Kozlov',
                      'Kriisa', 'Kroon', 'Krõlov', 'Kudrjavtsev', 'Kulikov',
                      'Kuningas', 'Kurg', 'Kurm', 'Kurvits', 'Kutsar', 'Kuus',
                      'Kuuse', 'Kuusik', 'Kuusk', 'Kärner', 'Käsper', 'Käär',
                      'Käärik', 'Kõiv', 'Kütt', 'Laan', 'Laane', 'Laanemets',
                      'Laas', 'Laht', 'Laine', 'Laks', 'Lang', 'Lass', 'Laur',
                      'Lauri', 'Lehiste', 'Leht', 'Lehtla', 'Lehtmets', 'Leis',
                      'Lember', 'Lepik', 'Lepp', 'Leppik', 'Liblik', 'Liiv',
                      'Liiva', 'Liivak', 'Liivamägi', 'Lill', 'Lillemets',
                      'Lind', 'Link', 'Lipp', 'Lokk', 'Lomp', 'Loorits', 'Luht',
                      'Luik', 'Lukin', 'Lukk', 'Lumi', 'Lumiste', 'Luts',
                      'Lätt', 'Lääne', 'Lääts', 'Lõhmus', 'Maasik', 'Madisson',
                      'Maidla', 'Mandel', 'Maripuu', 'Mark', 'Markus', 'Martin',
                      'Martinson', 'Meier', 'Meister', 'Melnik', 'Merila',
                      'Mets', 'Michelson', 'Mikk', 'Miller', 'Mitt', 'Moor',
                      'Muru', 'Must', 'Mäe', 'Mäeots', 'Mäesalu', 'Mägi',
                      'Mänd', 'Mändla', 'Männik', 'Männiste', 'Mõttus',
                      'Mölder', 'Mürk', 'Müür', 'Müürsepp', 'Niit', 'Nurk',
                      'Nurm', 'Nuut', 'Nõmm', 'Nõmme', 'Nõmmik', 'Oja', 'Ojala',
                      'Ojaste', 'Oks', 'Olesk', 'Oras', 'Orav', 'Org', 'Ots',
                      'Ott', 'Paal', 'Paap', 'Paas', 'Paju', 'Pajula', 'Palm',
                      'Palu', 'Parts', 'Pent', 'Peterson', 'Pettai', 'Pihelgas',
                      'Pihlak', 'Piho', 'Piir', 'Piirsalu', 'Pikk', 'Ploom',
                      'Poom', 'Post', 'Pruul', 'Pukk', 'Pulk', 'Puusepp',
                      'Pärn', 'Pärna', 'Pärnpuu', 'Pärtel', 'Põder', 'Põdra',
                      'Põld', 'Põldma', 'Põldmaa', 'Põllu', 'Püvi', 'Raadik',
                      'Raag', 'Raamat', 'Raid', 'Raidma', 'Raja', 'Rand',
                      'Randmaa', 'Randoja', 'Raud', 'Raudsepp', 'Rebane',
                      'Reimann', 'Reinsalu', 'Remmel', 'Rohtla', 'Roos',
                      'Roosileht', 'Roots', 'Rosenberg', 'Rosin', 'Ruus',
                      'Rätsep', 'Rüütel', 'Saar', 'Saare', 'Saks', 'Salu',
                      'Salumets', 'Salumäe', 'Sander', 'Sarap', 'Sarapuu',
                      'Sarv', 'Saul', 'Schmidt', 'Sepp', 'Sibul', 'Siim',
                      'Sikk', 'Sild', 'Sillaots', 'Sillaste', 'Silm', 'Simson',
                      'Sirel', 'Sisask', 'Sokk', 'Soo', 'Soon', 'Soosaar',
                      'Soosalu', 'Soots', 'Suits', 'Sulg', 'Susi', 'Sutt',
                      'Suur', 'Suvi', 'Säde', 'Sööt', 'Taal', 'Tali', 'Talts',
                      'Tamberg', 'Tamm', 'Tamme', 'Tammik', 'Teder', 'Teearu',
                      'Teesalu', 'Teras', 'Tiik', 'Tiits', 'Tilk', 'Tomingas',
                      'Tomson', 'Toom', 'Toome', 'Tooming', 'Toomsalu', 'Toots',
                      'Trei', 'Treial', 'Treier', 'Truu', 'Tuisk', 'Tuul',
                      'Tuulik', 'Täht', 'Tõnisson', 'Uibo', 'Unt', 'Urb', 'Uus',
                      'Uustalu', 'Vaher', 'Vaht', 'Vahter', 'Vahtra', 'Vain',
                      'Vaino', 'Valge', 'Valk', 'Vares', 'Varik', 'Veski',
                      'Viik', 'Viira', 'Viks', 'Vill', 'Villemson', 'Visnapuu',
                      'Vähi', 'Väli', 'Võsu', 'Õispuu', 'Õun', 'Õunapuu')

    last_names_rus = ('Abramov', 'Afanasjev', 'Aleksandrov', 'Alekseev',
                      'Andreev', 'Anissimov', 'Antonov', 'Baranov', 'Beljajev',
                      'Belov', 'Bogdanov', 'Bondarenko', 'Borissov', 'Bõstrov',
                      'Danilov', 'Davõdov', 'Denissov', 'Dmitriev', 'Drozdov',
                      'Egorov', 'Fedorov', 'Fedotov', 'Filatov', 'Filippov',
                      'Fjodorov', 'Fomin', 'Frolov', 'Gavrilov', 'Gerassimov',
                      'Golubev', 'Gontšarov', 'Gorbunov', 'Grigoriev', 'Gromov',
                      'Gusev', 'Ignatjev', 'Iljin', 'Ivanov', 'Jakovlev',
                      'Jefimov', 'Jegorov', 'Jermakov', 'Jeršov', 'Kalinin',
                      'Karpov', 'Karpov', 'Kazakov', 'Kirillov', 'Kisseljov',
                      'Klimov', 'Kolesnik', 'Komarov', 'Kondratjev',
                      'Konovalov', 'Konstantinov', 'Korol', 'Kostin', 'Kotov',
                      'Koval', 'Kozlov', 'Kruglov', 'Krõlov', 'Kudrjavtsev',
                      'Kulikov', 'Kuzmin', 'Kuznetsov', 'Lebedev', 'Loginov',
                      'Lukin', 'Makarov', 'Maksimov', 'Malõšev', 'Maslov',
                      'Matvejev', 'Medvedev', 'Melnik', 'Mihhailov', 'Miller',
                      'Mironov', 'Moroz', 'Naumov', 'Nazarov', 'Nikiforov',
                      'Nikitin', 'Nikolaev', 'Novikov', 'Orlov', 'Ossipov',
                      'Panov', 'Pavlov', 'Petrov', 'Poljakov', 'Popov',
                      'Romanov', 'Rosenberg', 'Rumjantsev', 'Safronov',
                      'Saveljev', 'Semenov', 'Sergejev', 'Sidorov', 'Smirnov',
                      'Sobolev', 'Sokolov', 'Solovjov', 'Sorokin', 'Stepanov',
                      'Suvorov', 'Tarassov', 'Tihhomirov', 'Timofejev', 'Titov',
                      'Trofimov', 'Tsvetkov', 'Vasiliev', 'Vinogradov',
                      'Vlassov', 'Volkov', 'Vorobjov', 'Voronin', 'Zahharov',
                      'Zaitsev', 'Zujev', 'Ševtšenko', 'Štšerbakov',
                      'Štšerbakov', 'Žukov', 'Žuravljov')
    last_names = set(last_names_est + last_names_rus)

    def first_name_male_est(self):
        return self.random_element(self.first_names_male_est)

    def first_name_female_est(self):
        return self.random_element(self.first_names_female_est)

    def first_name_male_rus(self):
        return self.random_element(self.first_names_male_rus)

    def first_name_female_rus(self):
        return self.random_element(self.first_names_female_rus)

    def first_name_est(self):
        return self.random_element(self.first_names_est)

    def first_name_rus(self):
        return self.random_element(self.first_names_rus)

    def last_name_est(self):
        return self.random_element(self.last_names_est)

    def last_name_rus(self):
        return self.random_element(self.last_names_rus)



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as CompanyProvider

class Provider(CompanyProvider):
    formats = (
        '{{company_prefix}} «{{last_name}}»',
        '{{company_prefix}} «{{last_name}} {{last_name}}»',
        '{{company_prefix}} «{{last_name}}-{{last_name}}»',
        '{{company_prefix}} «{{last_name}}, {{last_name}} и {{last_name}}»',
        '{{last_name}}',
    )

    company_prefixes = (
        'РАО', 'АО', 'ИП', 'НПО',
    )

    def company_prefix(self):
        return self.random_element(self.company_prefixes)



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as InternetProvider


class Provider(InternetProvider):

    free_email_domains = (
        'gmail.com', 'yahoo.com', 'hotmail.com', 'yahoo.com.au', 'hotmail.com.au',
    )

    tlds = ('com', 'com.au', 'org', 'org.au', 'net', 'net.au', 'biz', 'info', 'edu', 'edu.au')



# coding=utf-8
from __future__ import unicode_literals


from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):
    DAY_NAMES = {
        '0': 'السبت',
        '1': 'الأحد',
        '2': 'الإثنين',
        '3': 'الثلاثاء',
        '4': 'الأربعاء',
        '5': 'الخميس',
        '6': 'الجمعة',
    }

    MONTH_NAMES = {
        '01': 'كانون الثّاني',
        '02': 'شباط',
        '03': 'آذار',
        '04': 'نيسان',
        '05': 'أيّار',
        '06': 'حزيران',
        '07': 'تمّوز',
        '08': 'آب',
        '09': 'أيلول',
        '10': 'تشرين الأول',
        '11': 'تشرين الثاني',
        '12': 'كانون الأول'
    }

    centuries = [
        'الأول', 'الثاني', 'الثالث', 'الرابع', 'الخامس', 'السادس',
        'السابع', 'الثامن', 'التاسع', 'العاشر', 'الحادي عشر',
        'الثاني عشر', 'الثالث عشر', 'الرابع عشر', 'الخامس عشر',
        'السادس عشر', 'الثامن عشر', 'التاسع عشر', 'العشرين',
        'الحادي والعشرين', 'الثاني والعشرين',
    ]

    countries = [
        {'timezones': ['أوروب/أندورا'], 'code': 'AD', 'continent': 'أوروبا', 'name': 'أندورا', 'capital': 'أندورا لا فيلا'},
        {'timezones': ['آسيا/كابل'], 'code': 'AF', 'continent': 'آسيا', 'name': 'أفغانستان', 'capital': 'كابل'},
        {'timezones': ['أمريكا/أنتيغوا'], 'code': 'AG', 'continent': 'أمريكا الشمالية', 'name': 'أنتيغوا وباربودا', 'capital': "سانت جونز"},
        {'timezones': ['أوروبا/تيرانا'], 'code': 'AL', 'continent': 'أوروبا', 'name': 'ألبانيا', 'capital': 'تيرانا'},
        {'timezones': ['آسيا/يريفان'], 'code': 'AM', 'continent': 'آسيا', 'name': 'أرمينيا', 'capital': 'يريفان'},
        {'timezones': ['إفريقيا/لواندا'], 'code': 'AO', 'continent': 'إفريقيا', 'name': 'أنغولا', 'capital': 'لواندا'},
        {'timezones': ['أمريكا/الأرجنتين/بوينس_آيرس', 'أمريكا/الأرجنتين/Cordoba', 'أمريكا/الأرجنتين/خوخوي', 'أمريكا/الأرجنتين/توكومان', 'أمريكا/الأرجنتين/كاتاماركا', 'أمريكا/الأرجنتين/لا_ريوخا', 'أمريكا/الأرجنتين/سان_خوان', 'أمريكا/الأرجنتين/مندوزا', 'أمريكا/الأرجنتين/ريو_غاليغوس', 'أمريكا/الأرجنتين/أوشوايا'], 'code': 'AR', 'continent': 'أمريكا الجنوبية', 'name': 'الأرجنتين', 'capital': 'بوينس آيرس'},
        {'timezones': ['أوروبا/النمسا'], 'code': 'AT', 'continent': 'أوروبا', 'name': 'النمسا', 'capital': 'فيينا'},
        {'timezones': ['أستراليا/لورد_هاو', 'أستراليا/هوبارت', 'أستراليا/كري', 'أستراليا/ملبورن', 'أستراليا/سدني', 'أستراليا/بروكن_هل', 'أستراليا/بريزبن', 'أستراليا/ليندمان', 'أستراليا/أديلايد', 'أستراليا/داروين', 'أستراليا/برث'], 'code': 'AU', 'continent': 'أوقيانوسيا', 'name': 'أستراليا', 'capital': 'كانبرا'},
        {'timezones': ['آسيا/باكو'], 'code': 'AZ', 'continent': 'آسيا', 'name': 'أذربيجان', 'capital': 'باكو'},
        {'timezones': ['أمريكا/باربادوس'], 'code': 'BB', 'continent': 'أمريكا الشمالية', 'name': 'باربادوس', 'capital': 'بريدج تاون'},
        {'timezones': ['آسيا/دكا'], 'code': 'BD', 'continent': 'آسيا', 'name': 'بنغلادش', 'capital': 'دكا'},
        {'timezones': ['أوروبا/بروكسل'], 'code': 'BE', 'continent': 'أوروبا', 'name': 'بلجيكا', 'capital': 'بروكسل'},
        {'timezones': ['إفريقيا/واغادوغو'], 'code': 'BF', 'continent': 'إفريقيا', 'name': 'بوركينا فاسو', 'capital': 'واغادوغو'},
        {'timezones': ['أوروبا/صوفيا'], 'code': 'BG', 'continent': 'أوروبا', 'name': 'بلغاريا', 'capital': 'صوفيا'},
        {'timezones': ['آسيا/البحرين'], 'code': 'BH', 'continent': 'آسيا', 'name': 'البحرين', 'capital': 'المنامة'},
        {'timezones': ['إفريقيا/بوجمبورا'], 'code': 'BI', 'continent': 'إفريقيا', 'name': 'بوروندي', 'capital': 'بوجمبورا'},
        {'timezones': ['إفريقيا/بورتو نوفو'], 'code': 'BJ', 'continent': 'إفريقيا', 'name': 'بنين', 'capital': 'بورتو نوفو'},
        {'timezones': ['آسيا/بروناي'], 'code': 'BN', 'continent': 'آسيا', 'name': 'اتحاد بروناي (دار السلام)', 'capital': 'بندر سري بكاوان'},
        {'timezones': ['أمريكا/لاباز'], 'code': 'BO', 'continent': 'أمريكا الجنوبية', 'name': 'بوليفيا', 'capital': 'سوكري'},
        {'timezones': ['أمريكا/نورونها', 'أمريكا/بليم','أمريكا/فورتاليزا', 'أمريكا/ريسيفي', 'أمريكا/أراغوينا', 'أمريكا/ماسايو', 'أمريكا/باهيا', 'أمريكا/ساو_باولو', 'أمريكا/كامبو_غراندي', 'أمريكا/كويابا', 'أمريكا/بورتو_فاليو', 'أمريكا/بوا_فيستا', 'أمريكا/ماناوس', 'أمريكا/إيرونيبي', 'أمريكا/ريو_برانكو'], 'code': 'BR', 'continent': 'أمريكا الجنوبية', 'name': 'البرازيل', 'capital': 'برازيليا'},
        {'timezones': ['أمريكا/ناساو'], 'code': 'BS', 'continent': 'أمريكا الشمالية', 'name': 'باهاماس', 'capital': 'ناساو'},
        {'timezones': ['آسيا/تيمفو'], 'code': 'BT', 'continent': 'آسيا', 'name': 'بوتان', 'capital': 'تيمفو'},
        {'timezones': ['إفريقيا/غابورون'], 'code': 'BW', 'continent': 'إفريقيا', 'name': 'بوتسوانا', 'capital': 'غابورون'},
        {'timezones': ['أوروبا/مينسك'], 'code': 'BY', 'continent': 'أوروبا', 'name': 'روسيا البيضاء', 'capital': 'مينسك'},
        {'timezones': ['أمريكا/بليز'], 'code': 'BZ', 'continent': 'أمريكا الشمالية', 'name': 'بليز', 'capital': 'بلموبان'},
        {'timezones': ['أمريكا/سينت_جونز', 'أمريكا/هاليفاكس', 'أمريكا/جليس_باي', 'أمريكا/مونكتون', 'أمريكا/جووس_باي', 'أمريكا/بلانك_سابلون', 'أمريكا/مونتريال', 'أمريكا/تورونتو', 'أمريكا/نيبيغون', 'أمريكا/ثاندر_باي', 'أمريكا/بانغيرتانغ', 'أمريكا/إيكواليوت', 'أمريكا/أتيكوكان', 'أمريكا/رانكن_إنلت', 'أمريكا/وينيبيغ', 'أمريكا/رايني_ريفر', 'أمريكا/كامبريدج_باي', 'أمريكا/ريجينا', 'أمريكا/سويفت_كارنت', 'أمريكا/إدمونتون', 'أمريكا/يلو_نايف', 'أمريكا/إنوفك', 'أمريكا/دوسن_كريك', 'أمريكا/فانكوفر', 'أمريكا/وايت_هورس', 'أمريكا/داوسون'], 'code': 'CA', 'continent': 'أمريكا الشمالية', 'name': 'كندا', 'capital': 'أوتاوا'},
        {'timezones': ['إفريقيا/كينشاسا', 'إفريقيا/لوبومباشي'], 'code': 'CD', 'continent': 'إفريقيا', 'name': 'جمهورية الكونغو الديمقراطية', 'capital': 'كينشاسا'},
        {'timezones': ['إفريقيا/برازافيل'], 'code': 'CG', 'continent': 'إفريقيا', 'name': 'جمهورية الكونغو', 'capital': 'برازافيل'},
        {'timezones': ['إفريقيا/أبيدجان'], 'code': 'CI', 'continent': 'إفريقيا', 'name': "ساحل العاج", 'capital': 'ياموسوكرو'},
        {'timezones': ['أمريكا/سانتياغو', 'المحيط_الهاديء/جزيرة_القيامة'], 'code': 'CL', 'continent': 'أمريكا الجنوبية', 'name': 'تشيلي', 'capital': 'سانتياغو'},
        {'timezones': ['إفريقيا/دوالا'], 'code': 'CM', 'continent': 'إفريقيا', 'name': 'الكاميرون', 'capital': 'ياوندي'},
        {'timezones': ['آسيا/شانغهاي', 'آسيا/هاربن', 'آسيا/تشونغتشينغ', 'آسيا/أورومتشي', 'آسيا/كاشغر'], 'code': 'CN', 'continent': 'آسيا', 'name': "جمهورية الصين الشعبية", 'capital': 'بكين'},
        {'timezones': ['أمريكا/بوغوتا'], 'code': 'CO', 'continent': 'أمريكا الجنوبية', 'name': 'كولومبيا', 'capital': 'بوغوتا'},
        {'timezones': ['أمريكا/كوستاريكا'], 'code': 'CR', 'continent': 'أمريكا الشمالية', 'name': 'كوستاريكا', 'capital': 'سان خوسيه'},
        {'timezones': ['أمريكا/هافانا'], 'code': 'CU', 'continent': 'أمريكا الشمالية', 'name': 'كوبا', 'capital': 'هافانا'},
        {'timezones': ['الأطلنطي/الرأس_الأخضر'], 'code': 'CV', 'continent': 'إفريقيا', 'name': 'جمهورية الرأس الأخضر', 'capital': 'برايا'},
        {'timezones': ['آسيا/نيقوسيا'], 'code': 'CY', 'continent': 'آسيا', 'name': 'قبرص', 'capital': 'نيقوسيا'},
        {'timezones': ['أوروبا/براغ'], 'code': 'CZ', 'continent': 'أوروبا', 'name': 'جمهورية التشيك', 'capital': 'براغ'},
        {'timezones': ['أوروبا/برلين'], 'code': 'DE', 'continent': 'أوروبا', 'name': 'ألمانيا', 'capital': 'برلين'},
        {'timezones': ['إفريقيا/جيبوتي'], 'code': 'DJ', 'continent': 'إفريقيا', 'name': 'جيبوتي', 'capital': 'جيبوتي'},
        {'timezones': ['أوروبا/كوبنهاغن'], 'code': 'DK', 'continent': 'أوروبا', 'name': 'الدنمارك', 'capital': 'كوبنهاغن'},
        {'timezones': ['أمريكا/دومينيكا'], 'code': 'DM', 'continent': 'أمريكا الشمالية', 'name': 'دومينيكا', 'capital': 'روسياو'},
        {'timezones': ['أمريكا/سانتو_دومينغو'], 'code': 'DO', 'continent': 'أمريكا الشمالية', 'name': 'جمهورية الدومينيكان', 'capital': 'سانتو دومينغو'},
        {'timezones': ['أمريكا/غواياكيل', 'المحيط_الهاديء/أرخبيل_غالاباغوس'], 'code': 'EC', 'continent': 'أمريكا الجنوبية', 'name': 'الإكوادور', 'capital': 'كيتو'},
        {'timezones': ['أوروبا/تالين'], 'code': 'EE', 'continent': 'أوروبا', 'name': 'إستونيا', 'capital': 'تالين'},
        {'timezones': ['إفريقيا/القاهرة'], 'code': 'EG', 'continent': 'إفريقيا', 'name': 'مصر', 'capital': 'القاهرة'},
        {'timezones': ['إفريقيا/أسمرة'], 'code': 'ER', 'continent': 'إفريقيا', 'name': 'إرتيريا', 'capital': 'أسمرة'},
        {'timezones': ['إفريقيا/أديس أبابا'], 'code': 'ET', 'continent': 'إفريقيا', 'name': 'إثيوبيا', 'capital': 'أديس أبابا'},
        {'timezones': ['أوروبا/هلسنكي'], 'code': 'FI', 'continent': 'أوروبا', 'name': 'فنلندا', 'capital': 'هلسنكي'},
        {'timezones': ['المحيط_الهاديء/فيجي'], 'code': 'FJ', 'continent': 'أوقيانوسيا', 'name': 'فيجي', 'capital': 'سوفا'},
        {'timezones': ['أوروبا/باريس'], 'code': 'FR', 'continent': 'أوروبا', 'name': 'فرنسا', 'capital': 'باريس'},
        {'timezones': ['إفريقيا/ليبرفيل'], 'code': 'GA', 'continent': 'إفريقيا', 'name': 'الغابون', 'capital': 'ليبرفيل'},
        {'timezones': ['آسيا/تبليسي'], 'code': 'GE', 'continent': 'آسيا', 'name': 'جورجيا', 'capital': 'تبليسي'},
        {'timezones': ['إفريقيا/أكرا'], 'code': 'GH', 'continent': 'إفريقيا', 'name': 'غانا', 'capital': 'أكرا'},
        {'timezones': ['إفريقيا/بانجول'], 'code': 'GM', 'continent': 'إفريقيا', 'name': 'غامبيا', 'capital': 'بانجول'},
        {'timezones': ['إفريقيا/كوناكري'], 'code': 'GN', 'continent': 'إفريقيا', 'name': 'غينيا', 'capital': 'كوناكري'},
        {'timezones': ['أوروبا/أثينا'], 'code': 'GR', 'continent': 'أوروبا', 'name': 'اليونان', 'capital': 'أثينا'},
        {'timezones': ['أمريكا/غواتيمالا'], 'code': 'GT', 'continent': 'أمريكا الشمالية', 'name': 'غواتيمالا', 'capital': 'غواتيمالا سيتي'},
        {'timezones': ['أمريكا/غواتيمالا'], 'code': 'GT', 'continent': 'أمريكا الشمالية', 'name': 'هايتي', 'capital': 'بورت أو برانس'},
        {'timezones': ['إفريقيا/بيساو'], 'code': 'GW', 'continent': 'إفريقيا', 'name': 'غينيا بيساو', 'capital': 'بيساو'},
        {'timezones': ['أمريكا/غيانا'], 'code': 'GY', 'continent': 'أمريكا الجنوبية', 'name': 'غيانا', 'capital': 'جورج تاون'},
        {'timezones': ['أمريكا/تيجوسيجالبا'], 'code': 'HN', 'continent': 'أمريكا الشمالية', 'name': 'هندوراس', 'capital': 'تيجوسيجالبا'},
        {'timezones': ['أوروبا/بودابست'], 'code': 'HU', 'continent': 'أوروبا', 'name': 'هنغاريا', 'capital': 'بودابست'},
        {'timezones': ['آسيا/جاكرتا', 'آسيا/بونتياناك', 'آسيا/ماكاسار', 'آسيا/جايابورا'], 'code': 'ID', 'continent': 'آسيا', 'name': 'إندونسيا', 'capital': 'جاكرتا'},
        {'timezones': ['أوروبا/دبلن'], 'code': 'IE', 'continent': 'أوروبا', 'name': 'إيرلندا', 'capital': 'دبلن'},
        {'timezones': ['آسيا/القدس'], 'code': 'IL', 'continent': 'آسيا', 'name': 'فلسطين', 'capital': 'القدس'},
        {'timezones': ['آسيا/كالكتا'], 'code': 'IN', 'continent': 'آسيا', 'name': 'الهند', 'capital': 'نيو دلهي'},
        {'timezones': ['آسيا/بغداد'], 'code': 'IQ', 'continent': 'آسيا', 'name': 'العراق', 'capital': 'بغداد'},
        {'timezones': ['آسيا/طهران'], 'code': 'IR', 'continent': 'آسيا', 'name': 'إيران', 'capital': 'طهران'},
        {'timezones': ['الأطلنطي/ريكيافيك'], 'code': 'IS', 'continent': 'أوروبا', 'name': 'آيسلندا', 'capital': 'ريكيافيك'},
        {'timezones': ['أوروبا/روما'], 'code': 'IT', 'continent': 'أوروبا', 'name': 'إيطاليا', 'capital': 'روما'},
        {'timezones': ['أمريكا/جامايكا'], 'code': 'JM', 'continent': 'أمريكا الشمالية', 'name': 'جامايكا', 'capital': 'كينغستون'},
        {'timezones': ['آسيا/عمّان'], 'code': 'JO', 'continent': 'آسيا', 'name': 'الأردن', 'capital': 'عمّان'},
        {'timezones': ['آسيا/طوكيو'], 'code': 'JP', 'continent': 'آسيا', 'name': 'اليابان', 'capital': 'طوكيو'},
        {'timezones': ['إفريقيا/نيروبي'], 'code': 'KE', 'continent': 'إفريقيا', 'name': 'كينيا', 'capital': 'نيروبي'},
        {'timezones': ['آسيا/بشكيك'], 'code': 'KG', 'continent': 'آسيا', 'name': 'قيرغيزستان', 'capital': 'بشكيك'},
        {'timezones': ['المحيط_الهاديء/تاراوا', 'المحيط_الهاديء/إيديربيري', 'المحيط_الهاديء/كريتيماتي'], 'code': 'KI', 'continent': 'أوقيانوسيا', 'name': 'كيريباتي', 'capital': 'جنوب تاراوا'},
        {'timezones': ['آسيا/بيونغ_يانغ'], 'code': 'KP', 'continent': 'آسيا', 'name': 'كوريا الشمالية', 'capital': 'بيونغ يانغ'},
        {'timezones': ['آسيا/سيؤول'], 'code': 'KR', 'continent': 'آسيا', 'name': '؛كوريا الجنوبية', 'capital': 'سيؤول'},
        {'timezones': ['آسيا/الكويت'], 'code': 'KW', 'continent': 'آسيا', 'name': 'الكويت', 'capital': 'الكويت'},
        {'timezones': ['آسيا/بيروت'], 'code': 'LB', 'continent': 'آسيا', 'name': 'لبنان', 'capital': 'بيروت'},
        {'timezones': ['أوروبا/فادوز'], 'code': 'LI', 'continent': 'أوروبا', 'name': 'ليختنشتاين', 'capital': 'فادوز'},
        {'timezones': ['إفريقيا/مونروفيا'], 'code': 'LR', 'continent': 'إفريقيا', 'name': 'ليبيريا', 'capital': 'مونروفيا'},
        {'timezones': ['إفريقيا/ماسيرو'], 'code': 'LS', 'continent': 'إفريقيا', 'name': 'ليسوتو', 'capital': 'ماسيرو'},
        {'timezones': ['أوروبا/فيلنيوس'], 'code': 'LT', 'continent': 'أوروبا', 'name': 'ليتوانيا', 'capital': 'فيلنيوس'},
        {'timezones': ['أوروبا/لوكسمبرغ'], 'code': 'LU', 'continent': 'أوروبا', 'name': 'لوكسمبرغ', 'capital': 'لوكسمبرغ سيتي'},
        {'timezones': ['أوروبا/ربيغ'], 'code': 'LV', 'continent': 'أوروبا', 'name': 'لاتفيا', 'capital': 'ربيغ'},
        {'timezones': ['إفريقيا/طرابلس'], 'code': 'LY', 'continent': 'إفريقيا', 'name': 'ليبيا', 'capital': 'طرابلس'},
        {'timezones': ['الهندي/أنتاناناريفو'], 'code': 'MG', 'continent': 'إفريقيا', 'name': 'مدغشقر', 'capital': 'أنتاناناريفو'},
        {'timezones': ['المحيط_الهاديء/ماجورو', 'المحيط_الهاديء/كواجلين_أتول'], 'code': 'MH', 'continent': 'أوقيانوسيا', 'name': 'جزر مارشال', 'capital': 'ماجورو'},
        {'timezones': ['أوروبا/سكوبيه'], 'code': 'MK', 'continent': 'أوروبا', 'name': 'جمهورية مقدونيا', 'capital': 'سكوبيه'},
        {'timezones': ['إفريقيا/باماكو'], 'code': 'ML', 'continent': 'إفريقيا', 'name': 'مالي', 'capital': 'باماكو'},
        {'timezones': ['آسيا/رانغون'], 'code': 'MM', 'continent': 'آسيا', 'name': 'ميانمار', 'capital': 'نايبيداو'},
        {'timezones': ['آسيا/أولان_باتور', 'آسيا/Hovd', 'آسيا/تشويبالسان'], 'code': 'MN', 'continent': 'آسيا', 'name': 'مانغوليا', 'capital': 'أولان باتور'},
        {'timezones': ['إفريقيا/نواكشط'], 'code': 'MR', 'continent': 'إفريقيا', 'name': 'موريتانيا', 'capital': 'نواكشط'},
        {'timezones': ['أوروبا/مالطا'], 'code': 'MT', 'continent': 'أوروبا', 'name': 'مالطا', 'capital': 'فاليتا'},
        {'timezones': ['الهندي/موريشيوس'], 'code': 'MU', 'continent': 'إفريقيا', 'name': 'موريشيوس', 'capital': 'بور لويس'},
        {'timezones': ['الهندي/جزر_المالديف'], 'code': 'MV', 'continent': 'آسيا', 'name': 'جمهورية المالديف', 'capital': 'ماليه'},
        {'timezones': ['إفريقيا/بلانتاير'], 'code': 'MW', 'continent': 'إفريقيا', 'name': 'ملاوي', 'capital': 'ليلونغوي'},
        {'timezones': ['أمريكا/ميكسيكو_سيتي', 'أمريكا/كانكون', 'أمريكا/ميرديا', 'أمريكا/مونتيري', 'أمريكا/مازاتلان', 'أمريكا/شيواوا', 'أمريكا/ارموسييو_سونورا', 'أمريكا/تيخوانا'], 'code': 'MX', 'continent': 'أمريكا الشمالية', 'name': 'المكسيك', 'capital': 'ميكسيكو سيتي§'},
        {'timezones': ['آسيا/كوالا_لامبور', 'آسيا/Kuching'], 'code': 'MY', 'continent': 'آسيا', 'name': 'ماليزيا', 'capital': 'كوالا لامبور'},
        {'timezones': ['إفريقيا/مابوتو'], 'code': 'MZ', 'continent': 'إفريقيا', 'name': 'موزمبيق', 'capital': 'مابوتو'},
        {'timezones': ['إفريقيا/ويندهوك'], 'code': 'NA', 'continent': 'إفريقيا', 'name': 'ناميبيا', 'capital': 'ويندهوك'},
        {'timezones': ['إفريقيا/نيامي'], 'code': 'NE', 'continent': 'إفريقيا', 'name': 'النيجر', 'capital': 'نيامي'},
        {'timezones': ['إفريقيا/لاغوس'], 'code': 'NG', 'continent': 'إفريقيا', 'name': 'نيجيريا', 'capital': 'أبوجا'},
        {'timezones': ['أمريكا/ماناغوا'], 'code': 'NI', 'continent': 'أمريكا الشمالية', 'name': 'نيكاراغوا', 'capital': 'ماناغوا'},
        {'timezones': ['أوروبا/أمستردام'], 'code': 'NL', 'continent': 'أوروبا', 'name': 'هولندا', 'capital': 'أمستردام'},
        {'timezones': ['أوروبا/أوسلو'], 'code': 'NO', 'continent': 'أوروبا', 'name': 'النرويج', 'capital': 'أوسلو'},
        {'timezones': ['آسيا/كاتماندو'], 'code': 'NP', 'continent': 'آسيا', 'name': 'النيبال', 'capital': 'كاتماندو'},
        {'timezones': ['المحيط_الهاديء/ناورو'], 'code': 'NR', 'continent': 'أوقيانوسيا', 'name': 'ناورو', 'capital': 'يارين'},
        {'timezones': ['المحيط_الهاديء/أوكلاند', 'المحيط_الهاديء/تشاتهام'], 'code': 'NZ', 'continent': 'أوقيانوسيا', 'name': 'نيوزيلاندا', 'capital': 'ويلينغتون'},
        {'timezones': ['آسيا/مسقط'], 'code': 'OM', 'continent': 'آسيا', 'name': 'عمان', 'capital': 'مسقط'},
        {'timezones': ['أمريكا/بنما'], 'code': 'PA', 'continent': 'أمريكا الشمالية', 'name': 'بنما', 'capital': 'بنما'},
        {'timezones': ['أمريكا/ليما'], 'code': 'PE', 'continent': 'أمريكا الجنوبية', 'name': 'البيرو', 'capital': 'ليما'},
        {'timezones': ['المحيط_الهاديء/بورت_مورسبي'], 'code': 'PG', 'continent': 'أوقيانوسيا', 'name': 'بابوا غينيا الجديدة', 'capital': 'بورت مورسبي'},
        {'timezones': ['آسيا/مانيلا'], 'code': 'PH', 'continent': 'آسيا', 'name': 'الفيليبين', 'capital': 'مانيلا'},
        {'timezones': ['آسيا/كاراتشي'], 'code': 'PK', 'continent': 'آسيا', 'name': 'باكستان', 'capital': 'إسلام أباد'},
        {'timezones': ['أوروبا/وارسو'], 'code': 'PL', 'continent': 'أوروبا', 'name': 'بولندا', 'capital': 'وارسو'},
        {'timezones': ['أوروبا/لشبونة', 'الأطلنطي/ماديرا', 'الأطلنطي/الأزور'], 'code': 'PT', 'continent': 'أوروبا', 'name': 'البرتغال', 'capital': 'لشبونة'},
        {'timezones': ['المحيط_الهاديء/بالاو'], 'code': 'PW', 'continent': 'أوقيانوسيا', 'name': 'بالاو', 'capital': 'نجيرولمد'},
        {'timezones': ['أمريكا/أسونسيون'], 'code': 'PY', 'continent': 'أمريكا الجنوبية', 'name': 'بابرغوي', 'capital': 'أسونسيون'},
        {'timezones': ['آسيا/قطر'], 'code': 'QA', 'continent': 'آسيا', 'name': 'قطر', 'capital': 'الدوحة'},
        {'timezones': ['أوروبا/بوخارست'], 'code': 'RO', 'continent': 'أوروبا', 'name': 'رومانيا', 'capital': 'بوخارست'},
        {'timezones': ['أوروبا/كالينينغراد', 'أوروبا/موسكو', 'أوروبا/Volgograd', 'أوروبا/سمارة', 'آسيا/يكاترينبورغ', 'آسيا/أومسك', 'آسيا/نوفوسيبيرسك', 'آسيا/كراسنوياسك', 'آسيا/إروتسك', 'آسيا/ياكوتسك', 'آسيا/فالديفوستوك', 'آسيا/ساخالن', 'آسيا/ماغادان', 'آسيا/كامشتكا', 'آسيا/أنادير'], 'code': 'RU', 'continent': 'أوروبا', 'name': 'روسيا', 'capital': 'موسكو'},
        {'timezones': ['إفريقيا/كيغالي'], 'code': 'RW', 'continent': 'إفريقيا', 'name': 'رواندا', 'capital': 'كيغالي'},
        {'timezones': ['آسيا/الرياض'], 'code': 'SA', 'continent': 'آسيا', 'name': 'المملكة العربية السعودية', 'capital': 'الرياض'},
        {'timezones': ['المحيط_الهاديء/غوادالكانال'], 'code': 'SB', 'continent': 'أوقيانوسيا', 'name': 'جزر سولمون', 'capital': 'هونيارا'},
        {'timezones': ['الهندي/ماهي'], 'code': 'SC', 'continent': 'إفريقيا', 'name': 'سيشل', 'capital': 'فيكتوريا'},
        {'timezones': ['إفريقيا/الخرطوم'], 'code': 'SD', 'continent': 'إفريقيا', 'name': 'السودان', 'capital': 'الخرطوم'},
        {'timezones': ['أوروبا/ستوكهولم'], 'code': 'SE', 'continent':'أوروبا', 'name': 'السويد', 'capital': 'ستوكهولم'},
        {'timezones': ['آسيا/سنغافورة'], 'code': 'SG', 'continent': 'آسيا', 'name': 'سنغافورة', 'capital': 'سنغافورة'},
        {'timezones': ['أوروبا/ليوبليانا'], 'code': 'SI', 'continent': 'أوروبا', 'name': 'سلوفانيا', 'capital': 'ليوبليانا'},
        {'timezones': ['أوروبا/براتيسلافا'], 'code': 'SK', 'continent': 'أوروبا', 'name': 'سلوفاكيا', 'capital': 'براتيسلافا'},
        {'timezones': ['إفريقيا/فريتاون'], 'code': 'SL', 'continent': 'إفريقيا', 'name': 'سيراليون', 'capital': 'فريتاون'},
        {'timezones': ['أوروبا/سان_مارينو'], 'code': 'SM', 'continent': 'أوروبا', 'name': 'جمهورية سان مارينو', 'capital': 'سان مارينو'},
        {'timezones': ['إفريقيا/داكار'], 'code': 'SN', 'continent': 'إفريقيا', 'name': 'السنغال', 'capital': 'داكار'},
        {'timezones': ['إفريقيا/مقديشو'], 'code': 'SO', 'continent': 'إفريقيا', 'name': 'الصومال', 'capital': 'مقديشو'},
        {'timezones': ['أمريكا/باراماريبو'], 'code': 'SR', 'continent': 'أمريكا الجنوبية', 'name': 'Suriname', 'capital': 'باراماريبو'},
        {'timezones': ['إفريقيا/ساو_تومي'], 'code': 'ST', 'continent': 'إفريقيا', 'name': ' ساو تومي وبرينسيب', 'capital': 'ساو تومي'},
        {'timezones': ['آسيا/دممشق'], 'code': 'SY', 'continent': 'آسيا', 'name': 'سوريا', 'capital': 'دمشق'},
        {'timezones': ['إفريقيا/لومي'], 'code': 'TG', 'continent': 'إفريقيا', 'name': 'توغو', 'capital': 'لومي'},
        {'timezones': ['آسيا/بانغوك'], 'code': 'TH', 'continent': 'آسيا', 'name': 'تايلند', 'capital': 'بناغوك'},
        {'timezones': ['آسيا/دوشنبه'], 'code': 'TJ', 'continent': 'آسيا', 'name': 'طاجكيستان', 'capital': 'دوشنبه'},
        {'timezones': ['آسيا/عشق_آباد'], 'code': 'TM', 'continent': 'آسيا', 'name': 'تركمانستان', 'capital': 'عشق آباد'},
        {'timezones': ['إفريقيا/تونس'], 'code': 'TN', 'continent': 'إفريقيا', 'name': 'تونس', 'capital': 'تونس'},
        {'timezones': ['المحيط_الهاديء/تونغاتابو'], 'code': 'TO', 'continent': 'أوقيانوسيا', 'name': 'تونغا', 'capital': 'نوكو ألوفا'},
        {'timezones': ['أوروبا/إسطنبول'], 'code': 'TR', 'continent': 'آسيا', 'name': 'تركيا', 'capital': 'أنقرة'},
        {'timezones': ['أمريكا/بورت_أوف_سبين'], 'code': 'TT', 'continent': 'أمريكا الشمالية', 'name': 'ترينيداد وتوباغو', 'capital': 'بورت أوف سبين'},
        {'timezones': ['المحيط_الهاديء/فونافوتي'], 'code': 'TV', 'continent': 'أوقيانوسيا', 'name': 'توفالو', 'capital': 'فونافوتي'},
        {'timezones': ['إفريقيا/دار_السلام'], 'code': 'TZ', 'continent': 'إفريقيا', 'name': 'تانزانيا', 'capital': 'دودوما'},
        {'timezones': ['أوروبا/كييف', 'أوروبا/أوجهورود', 'أوروبا/زاباروجيا', 'أوروبا/سيمفروبول'], 'code': 'UA', 'continent': 'أوروبا', 'name': 'أوكرانيا', 'capital': 'كييف'},
        {'timezones': ['إفريقيا/كامبالا'], 'code': 'UG', 'continent': 'إفريقيا', 'name': 'أوغندا', 'capital': 'كامبالا'},
        {'timezones': ['أمريكا/نيويورك', 'أمريكا/ديترويت', 'أمريكا/كنتاكي/لويسفيل', 'أمريكا/كنتاكي/مونتيسللو', 'أمريكا/إنديانا/إنديانابولس', 'أمريكا/إنديانا/مارنغو', 'أمريكا/إنديانا/نوكس', 'أمريكا/إنديانا/فيفاي', 'أمريكا/شيكاغو', 'أمريكا/إنديانا/فانسان', 'أمريكا/إنديانا/بيترزبيرغ', 'أمريكا/مينومني', 'أمريكا/نورث_داكوتا/سينتر', 'أمريكا/نورث_داكوتا/نيو_سالم', 'أمريكا/دنفر', 'أمريكا/بويسي', 'أمريكا/شيبروك', 'أمريكا/فينيكس', 'أمريكا/لوس_أنجيلوس', 'أمريكا/أنكوريج', 'أمريكا/جونو', 'أمريكا/ياكوتات', 'أمريكا/نوم', 'أمريكا/أداك', 'المحيط_الهاديء/هونولولو'], 'code': 'US', 'continent': 'أمريكا الشمالية', 'name': 'الولايات المتحدة الأمريكية', 'capital': 'واشنطن'},
        {'timezones': ['أمريكا/مونتفيدو'], 'code': 'UY', 'continent': 'أمريكا الجنوبية', 'name': 'أوروغواي', 'capital': 'مونتفيدو'},
        {'timezones': ['آسيا/سمرقند', 'آسيا/طشقند'], 'code': 'UZ', 'continent': 'آسيا', 'name': 'أوزبكستان', 'capital': 'طشقند'},
        {'timezones': ['أوروبا/الفاتيكان'], 'code': 'VA', 'continent': 'أوروبا', 'name': 'الفاتيكان', 'capital': 'الفاتيكان'},
        {'timezones': ['أمريكا/كاركاس'], 'code': 'VE', 'continent': 'أمريكا الجنوبية', 'name': 'فنزويلا', 'capital': 'كاركاس'},
        {'timezones': ['آسيا/سايغون'], 'code': 'VN', 'continent': 'آسيا', 'name': 'فيتنام', 'capital': 'هانوي'},
        {'timezones': ['المحيط_الهاديء/أيفاتي'], 'code': 'VU', 'continent': 'أوقيانوسيا', 'name': 'فانواتو', 'capital': 'بورت فيلا'},
        {'timezones': ['آسيا/عدن'], 'code': 'YE', 'continent': 'آسيا', 'name': 'اليمن', 'capital': "صنعاء"},
        {'timezones': ['إفريقيا/لوساكا'], 'code': 'ZM', 'continent': 'إفريقيا', 'name': 'زامبيا', 'capital': 'لوساكا'},
        {'timezones': ['إفريقيا/هراري'], 'code': 'ZW', 'continent': 'إفريقيا', 'name': 'زيمبابوي', 'capital': 'هراري'},
        {'timezones': ['إفريقيا/الجزائر'], 'code': 'DZ', 'continent': 'إفريقيا', 'name': 'الجزائر', 'capital': 'الجزائر'},
        {'timezones': ['أوروبا/سراييفو'], 'code': 'BA', 'continent': 'أوروبا', 'name': 'البوسنة والهرسك', 'capital': 'سراييفو'},
        {'timezones': ['آسيا/بنوم_بنه'], 'code': 'KH', 'continent': 'آسيا', 'name': 'كمبوديا', 'capital': 'بنوم بنه'},
        {'timezones': ['إفريقيا/بانغي'], 'code': 'CF', 'continent': 'إفريقيا', 'name': 'جمهورية أفريقيا الوسطى', 'capital': 'بانغي'},
        {'timezones': ['إفريقيا/نجامينا'], 'code': 'TD', 'continent': 'إفريقيا', 'name': 'تشاد', 'capital': "نجامينا"},
        {'timezones': ['الهندي/كومورو'], 'code': 'KM', 'continent': 'إفريقيا', 'name': 'جزر القمر', 'capital': 'موروني'},
        {'timezones': ['أوروبا/زغرب'], 'code': 'HR', 'continent': 'أوروبا', 'name': 'كرواتيا', 'capital': 'زغرب'},
        {'timezones': ['آسيا/ديلي'], 'code': 'TL', 'continent': 'آسيا', 'name': 'تيمور الشرقية', 'capital': 'ديلي'},
        {'timezones': ['أمريكا/السلفادور'], 'code': 'SV', 'continent': 'أمريكا الشمالية', 'name': 'السلفادور', 'capital': 'سان سلفادور'},
        {'timezones': ['إفريقيا/مالابو'], 'code': 'GQ', 'continent': 'إفريقيا', 'name': 'غينيا الاستوائية', 'capital': 'مالابو'},
        {'timezones': ['أمريكا/غرينادا'], 'code': 'GD', 'continent': 'أمريكا الشمالية', 'name': 'غرينادا', 'capital': "سانت جورجز"},
        {'timezones': ['آسيا/ألماتي', 'آسيا/كيزيلوردا',  'آسيا/أقتوبي', 'آسيا/أقتاو', 'آسيا/أورال'], 'code': 'KZ', 'continent': 'آسيا', 'name': 'كازاخستان', 'capital': 'أستانة'},
        {'timezones': ['آسيا/فيينتيان'], 'code': 'LA', 'continent': 'آسيا', 'name': 'لاوس', 'capital': 'فيينتيان'},
        {'timezones': ['المحيط_الهاديء/تشوك', 'المحيط_الهاديء/بونابي', 'المحيط_الهاديء/كورساي'], 'code': 'FM', 'continent': 'أوقيانوسيا', 'name': 'ولايات ميكرونيسيا المتحدة', 'capital': 'باليكير'},
        {'timezones': ['أوروبا/كيشيناو'], 'code': 'MD', 'continent': 'أوروبا', 'name': 'مولدافيا', 'capital': 'كيشيناو'},
        {'timezones': ['أوروبا/موناكو'], 'code': 'MC', 'continent': 'أوروبا', 'name': 'موناكو', 'capital': 'موناكو'},
        {'timezones': ['أوروبا/بودغوريتسا'], 'code': 'ME', 'continent': 'أوروبا', 'name': 'الجبل الأسود', 'capital': 'بودغوريتسا'},
        {'timezones': ['إفريقيا/الدار_البيضاء'], 'code': 'MA', 'continent': 'إفريقيا', 'name': 'المغرب', 'capital': 'الرباط'},
        {'timezones': ['أمريكا/سانت_كيتس'], 'code': 'KN', 'continent': 'أمريكا الشمالية', 'name': 'سانت كيتس ونيفيس', 'capital': 'باستير'},
        {'timezones': ['أمريكا/سانت_لوسيا'], 'code': 'LC', 'continent': 'أمريكا الشمالية', 'name': 'سانت لوسيا', 'capital': 'كاستريس'},
        {'timezones': ['أمريكا/سينت_فينسينت'], 'code': 'VC', 'continent': 'أمريكا الشمالية', 'name': 'سانت فينسنت والغرينادين', 'capital': 'كينغستاون'},
        {'timezones': ['المحيط_الهاديء/أبيا'], 'code': 'WS', 'continent': 'أوقيانوسيا', 'name': 'ساموا', 'capital': 'أبيا'},
        {'timezones': ['أوروبا/بلغراد'], 'code': 'RS', 'continent': 'أوروبا', 'name': 'صربيا', 'capital': 'بلغراد'},
        {'timezones': ['إفريقيا/جوهانسبرغ'], 'code': 'ZA', 'continent': 'إفريقيا', 'name': 'جنوب إفريقيا', 'capital': 'بريتوريا'},
        {'timezones': ['أوروبا/مدريد', 'إفريقيا/سبتة', 'الأطلنطي/الكناري'], 'code': 'ES', 'continent': 'أوروبا', 'name': 'إسبانيا', 'capital': 'مدريد'},
        {'timezones': ['آسيا/كولمبو'], 'code': 'LK', 'continent': 'آسيا', 'name': 'سريلانكا', 'capital': 'سري جاياواردنابورا كوتي'},
        {'timezones': ['إفريقيا/مبابان'], 'code': 'SZ', 'continent': 'إفريقيا', 'name': 'سوازيلاند', 'capital': 'مبابان'},
        {'timezones': ['أوروبا/زيورخ'], 'code': 'CH', 'continent': 'أوروبا', 'name': 'سويسرا', 'capital': 'برن'},
        {'timezones': ['آسيا/دبي'], 'code': 'AE', 'continent': 'آسيا', 'name': 'الإمارات العربية المتحدة', 'capital': 'أبو ظبي'},
        {'timezones': ['أوروبا/لندن'], 'code': 'GB', 'continent': 'أوروبا', 'name': 'المملكة المتحدة', 'capital': 'لندن'},
    ]

    AM_PM = {
        'AM': 'ص',
        'PM': 'م',
    }

    def month_name(self):
        month = self.date('%m')
        return self.MONTH_NAMES[month]

    def am_pm(self):
        date = self.date('%p')
        return self.AM_PM[date]

    def day_of_week(self):
        day = self.date('%w')
        return self.DAY_NAMES[day]



# -*- encoding: utf-8 -*-
from __future__ import unicode_literals
from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = (
        '{{last_name}} {{company_suffix}}',
        '{{last_name}}-{{last_name}}',
        '{{company_prefix}} {{last_name}}-{{last_name}}',
        '{{company_prefix}} {{last_name}} y {{last_name}}',
        '{{company_prefix}} {{last_name}}, {{last_name}} y {{last_name}}',
        '{{last_name}}-{{last_name}} {{company_suffix}}',
        '{{last_name}}, {{last_name}} y {{last_name}}',
        '{{last_name}} y {{last_name}} {{company_suffix}}'
    )

    catch_phrase_words = (
        (
           "habilidad", "acceso", "adaptador", "algoritmo", "alianza",
           "analista", "aplicación", "enfoque", "arquitectura",
           "archivo", "inteligencia artificial", "array", "actitud",
           "medición", "gestión presupuestaria", "capacidad", "desafío",
           "circuito", "colaboración", "complejidad", "concepto",
           "conglomeración", "contingencia", "núcleo", "fidelidad",
           "base de datos", "data-warehouse", "definición", "emulación",
           "codificar", "encriptar", "extranet", "firmware",
           "flexibilidad", "focus group", "previsión", "base de trabajo",
           "función", "funcionalidad", "interfaz gráfica", "groupware",
           "interfaz gráfico de usuario", "hardware", "soporte", "jerarquía",
           "conjunto", "implementación", "infraestructura", "iniciativa",
           "instalación", "conjunto de instrucciones", "interfaz",
           "intranet", "base del conocimiento", "red de area local",
           "aprovechar", "matrices", "metodologías", "middleware",
           "migración", "modelo", "moderador", "monitorizar",
           "arquitectura abierta", "sistema abierto", "orquestar",
           "paradigma", "paralelismo", "política", "portal",
           "estructura de precios", "proceso de mejora",
           "producto", "productividad", "proyecto", "proyección",
           "protocolo", "línea segura", "software", "solución",
           "estandarización", "estrategia", "estructura", "éxito",
           "superestructura", "soporte", "sinergia", "mediante",
           "marco de tiempo", "caja de herramientas", "utilización",
           "website", "fuerza de trabajo"),
        (
            "24 horas", "24/7", "3ra generación", "4ta generación",
            "5ta generación", "6ta generación", "analizada",
            "asimétrica", "asíncrona", "monitorizada por red",
            "bidireccional", "bifurcada", "generada por el cliente",
            "cliente-servidor", "coherente", "cohesiva", "compuesto",
            "sensible al contexto", "basado en el contexto",
            "basado en contenido", "dedicada",
            "generado por la demanda", "didáctica", "direccional",
            "discreta", "dinámica", "potenciada", "acompasada",
            "ejecutiva", "explícita", "tolerante a fallos",
            "innovadora", "amplio abanico", "global", "heurística",
            "alto nivel", "holística", "homogénea", "híbrida",
            "incremental", "intangible", "interactiva", "intermedia",
            "local", "logística", "maximizada", "metódica",
            "misión crítica", "móvil", "modular", "motivadora",
            "multimedia", "multiestado", "multitarea", "nacional",
            "basado en necesidades", "neutral", "nueva generación",
            "no-volátil", "orientado a objetos", "óptima", "optimizada",
            "radical", "tiempo real", "recíproca", "regional",
            "escalable", "secundaria", "orientada a soluciones",
            "estable", "estática", "sistemática", "sistémica",
            "tangible", "terciaria", "transicional", "uniforme",
            "valor añadido", "vía web", "defectos cero", "tolerancia cero"
        ),
        (
            'adaptativo', 'avanzado', 'asimilado', 'automatizado',
            'balanceado', 'enfocado al negocio',
            'centralizado', 'clonado', 'compatible', 'configurable',
            'multiplataforma', 'enfocado al cliente', 'personalizable',
            'descentralizado', 'digitalizado', 'distribuido', 'diverso',
            'mejorado', 'en toda la empresa', 'ergonómico', 'exclusivo',
            'expandido', 'extendido', 'cara a cara', 'enfocado',
            'de primera línea', 'totalmente configurable',
            'basado en funcionalidad', 'fundamental', 'horizontal',
            'implementado', 'innovador', 'integrado', 'intuitivo',
            'inverso', 'administrado', 'mandatorio', 'monitoreado',
            'multicanal', 'multilateral', 'multi-capas', 'en red',
            'basado en objetos', 'de arquitectura abierta',
            'open-source', 'operativo', 'optimizado', 'opcional',
            'orgánico', 'organizado', 'perseverante', 'persistente',
            'polarizado', 'preventivo', 'proactivo', 'enfocado a ganancias',
            'programable', 'progresivo', 'llave pública',
            'enfocado a la calidad', 'reactivo', 'realineado',
            'recontextualizado', 'reducido', 'con ingeniería inversa',
            'de tamaño adecuado', 'robusto', 'seguro', 'compartible',
            'sincronizado', 'orientado a equipos', 'total',
            'universal', 'actualizable', 'centrado en el usuario',
            'versátil', 'virtual', 'visionario',
        )
    )

    bsWords = (
        (
            'implementa', 'utiliza', 'integra', 'optimiza',
            'evoluciona', 'transforma', 'abraza', 'habilita',
            'orquesta', 'reinventa', 'agrega', 'mejora', 'incentiva',
            'modifica', 'empodera', 'monetiza', 'fortalece',
            'facilita', 'sinergiza',  'crea marca', 'crece',
            'sintetiza', 'entrega', 'mezcla', 'incuba', 'compromete',
            'maximiza', 'visualiza', 'innova',
            'escala', 'libera', 'maneja', 'extiende', 'revoluciona',
            'genera', 'explota', 'transiciona', 'itera', 'cultiva',
            'redefine', 'recontextualiza',
        ),
        (
            'sinergias', 'paradigmas', 'marcados', 'socios',
            'infraestructuras', 'plataformas', 'iniciativas',
            'canales', 'communidades', 'ROI', 'soluciones',
            'portales', 'nichos', 'tecnologías', 'contenido',
            'cadena de producción', 'convergencia', 'relaciones',
            'arquitecturas', 'interfaces', 'comercio electrónico',
            'sistemas', 'ancho de banda', 'modelos', 'entregables',
            'usuarios', 'esquemas', 'redes', 'aplicaciones', 'métricas',
            'funcionalidades', 'experiencias', 'servicios web',
            'metodologías'
        ),
        (
            'valor agregado', 'verticales', 'proactivas', 'robustas',
            'revolucionarias', 'escalables', 'de punta', 'innovadoras',
            'intuitivas', 'estratégicas', 'e-business', 'de misión crítica',
            'uno-a-uno', '24/7', 'end-to-end', 'globales', 'B2B', 'B2C',
            'granulares', 'sin fricciones', 'virtuales', 'virales',
            'dinámicas', '24/365', 'magnéticas', 'listo para la web',
            'interactivas', 'punto-com', 'sexi', 'en tiempo real',
            'eficientes', 'front-end', 'distribuidas', 'extensibles',
            'llave en mano', 'de clase mundial', 'open-source',
            'plataforma cruzada', 'de paquete', 'empresariales',
            'integrado', 'impacto total', 'inalámbrica', 'transparentes',
            'de siguiente generación', 'lo último', 'centrado al usuario',
            'visionarias', 'personalizado', 'ubicuas', 'plug-and-play',
            'colaborativas', 'holísticas', 'ricas'
        ),
    )

    company_preffixes = ('Despacho', 'Grupo', 'Corporacin', 'Club',
                         'Industrias', 'Laboratorios', 'Proyectos')

    company_suffixes = ('A.C.', 'S.A.', 'S.A. de C.V.', 'S.C.',
        'S. R.L. de C.V.','e Hijos', 'y Asociados')

    def company_prefix(self):
        """
        Ejemplo: Grupo
        """
        return self.random_element(self.company_preffixes)

    def catch_phrase(self):
        """
        :example 'Robust full-range hub'
        """
        result = []
        for word_list in self.catch_phrase_words:
            result.append(self.random_element(word_list))

        return " ".join(result)

    def bs(self):
        """
        :example 'integrate extensible convergence'
        """
        result = []
        for word_list in self.bsWords:
            result.append(self.random_element(word_list))

        return " ".join(result)



# coding=utf-8

from __future__ import unicode_literals
import hashlib
import string
import uuid
import os
import sys

from .. import BaseProvider


class Provider(BaseProvider):
    # Locales supported by Linux Mint from `/usr/share/i18n/SUPPORTED`
    language_locale_codes = {
        'aa': ('DJ', 'ER', 'ET'), 'af': ('ZA',), 'ak': ('GH',), 'am': ('ET',),
        'an': ('ES',), 'apn': ('IN',),
        'ar': ('AE', 'BH', 'DJ', 'DZ', 'EG', 'EH', 'ER', 'IL', 'IN',
               'IQ', 'JO', 'KM', 'KW', 'LB', 'LY', 'MA', 'MR', 'OM',
               'PS', 'QA', 'SA', 'SD', 'SO', 'SS', 'SY', 'TD', 'TN',
               'YE'),
        'as': ('IN',), 'ast': ('ES',), 'ayc': ('PE',), 'az': ('AZ', 'IN'),
        'be': ('BY',), 'bem': ('ZM',), 'ber': ('DZ', 'MA'), 'bg': ('BG',),
        'bhb': ('IN',), 'bho': ('IN',), 'bn': ('BD', 'IN'), 'bo': ('CN', 'IN'),
        'br': ('FR',), 'brx': ('IN',), 'bs': ('BA',), 'byn': ('ER',),
        'ca': ('AD', 'ES', 'FR', 'IT'), 'ce': ('RU',), 'ckb': ('IQ',),
        'cmn': ('TW',), 'crh': ('UA',), 'cs': ('CZ',), 'csb': ('PL',),
        'cv': ('RU',), 'cy': ('GB',), 'da': ('DK',),
        'de': ('AT', 'BE', 'CH', 'DE', 'LI', 'LU'), 'doi': ('IN',),
        'dv': ('MV',), 'dz': ('BT',), 'el': ('GR', 'CY'),
        'en': ('AG', 'AU', 'BW', 'CA', 'DK', 'GB', 'HK', 'IE', 'IN', 'NG',
               'NZ', 'PH', 'SG', 'US', 'ZA', 'ZM', 'ZW'),
        'eo': ('US',),
        'es': ('AR', 'BO', 'CL', 'CO', 'CR', 'CU', 'DO', 'EC', 'ES', 'GT',
               'HN', 'MX', 'NI', 'PA', 'PE', 'PR', 'PY', 'SV', 'US', 'UY', 'VE'
               ), 'et': ('EE',), 'eu': ('ES', 'FR'), 'fa': ('IR',),
        'ff': ('SN',), 'fi': ('FI',), 'fil': ('PH',), 'fo': ('FO',),
        'fr': ('CA', 'CH', 'FR', 'LU'), 'fur': ('IT',), 'fy': ('NL', 'DE'),
        'ga': ('IE',), 'gd': ('GB',), 'gez': ('ER', 'ET'), 'gl': ('ES',),
        'gu': ('IN',), 'gv': ('GB',), 'ha': ('NG',), 'hak': ('TW',),
        'he': ('IL',), 'hi': ('IN',), 'hne': ('IN',), 'hr': ('HR',),
        'hsb': ('DE',), 'ht': ('HT',), 'hu': ('HU',), 'hy': ('AM',),
        'ia': ('FR',), 'id': ('ID',), 'ig': ('NG',), 'ik': ('CA',),
        'is': ('IS',), 'it': ('CH', 'IT'), 'iu': ('CA',), 'iw': ('IL',),
        'ja': ('JP',), 'ka': ('GE',), 'kk': ('KZ',), 'kl': ('GL',),
        'km': ('KH',), 'kn': ('IN',), 'ko': ('KR',), 'kok': ('IN',),
        'ks': ('IN',), 'ku': ('TR',), 'kw': ('GB',), 'ky': ('KG',),
        'lb': ('LU',), 'lg': ('UG',), 'li': ('BE', 'NL'), 'lij': ('IT',),
        'ln': ('CD',), 'lo': ('LA',), 'lt': ('LT',), 'lv': ('LV',),
        'lzh': ('TW',), 'mag': ('IN',), 'mai': ('IN',), 'mg': ('MG',),
        'mhr': ('RU',), 'mi': ('NZ',), 'mk': ('MK',), 'ml': ('IN',),
        'mn': ('MN',), 'mni': ('IN',), 'mr': ('IN',), 'ms': ('MY',),
        'mt': ('MT',), 'my': ('MM',), 'nan': ('TW',), 'nb': ('NO',),
        'nds': ('DE', 'NL'), 'ne': ('NP',), 'nhn': ('MX',),
        'niu': ('NU', 'NZ'), 'nl': ('AW', 'BE', 'NL'), 'nn': ('NO',),
        'nr': ('ZA',), 'nso': ('ZA',), 'oc': ('FR',), 'om': ('ET', 'KE'),
        'or': ('IN',), 'os': ('RU',), 'pa': ('IN', 'PK'),
        'pap': ('AN', 'AW', 'CW'), 'pl': ('PL',), 'ps': ('AF',),
        'pt': ('BR', 'PT'), 'quz': ('PE',), 'raj': ('IN',), 'ro': ('RO',),
        'ru': ('RU', 'UA'), 'rw': ('RW',), 'sa': ('IN',), 'sat': ('IN',),
        'sc': ('IT',), 'sd': ('IN', 'PK'), 'se': ('NO',), 'shs': ('CA',),
        'si': ('LK',), 'sid': ('ET',), 'sk': ('SK',), 'sl': ('SI',),
        'so': ('DJ', 'ET', 'KE', 'SO'), 'sq': ('AL', 'ML'), 'sr': ('ME', 'RS'),
        'ss': ('ZA',), 'st': ('ZA',), 'sv': ('FI', 'SE'), 'sw': ('KE', 'TZ'),
        'szl': ('PL',), 'ta': ('IN', 'LK'), 'tcy': ('IN',), 'te': ('IN',),
        'tg': ('TJ',), 'th': ('TH',), 'the': ('NP',), 'ti': ('ER', 'ET'),
        'tig': ('ER',), 'tk': ('TM',), 'tl': ('PH',), 'tn': ('ZA',),
        'tr': ('CY', 'TR'), 'ts': ('ZA',), 'tt': ('RU',), 'ug': ('CN',),
        'uk': ('UA',), 'unm': ('US',), 'ur': ('IN', 'PK'), 'uz': ('UZ',),
        've': ('ZA',), 'vi': ('VN',), 'wa': ('BE',), 'wae': ('CH',),
        'wal': ('ET',), 'wo': ('SN',), 'xh': ('ZA',), 'yi': ('US',),
        'yo': ('NG',), 'yue': ('HK',), 'zh': ('CN', 'HK', 'SG', 'TW'),
        'zu': ('ZA',)
    }

    def boolean(self, chance_of_getting_true=50):
        return self.generator.random.randint(1, 100) <= chance_of_getting_true

    def null_boolean(self):
        return {
            0: None,
            1: True,
            -1: False
        }[self.generator.random.randint(-1, 1)]

    def binary(self, length=(1 * 1024 * 1024)):
        """ Returns random binary blob.

        Default blob size is 1 Mb.
        """
        blob = [self.generator.random.randrange(256) for o in range(length)]
        return bytes(blob) if sys.version_info[0] >= 3 else bytearray(blob)

    def md5(self, raw_output=False):
        """
        Calculates the md5 hash of a given string
        :example 'cfcd208495d565ef66e7dff9f98764da'
        """
        res = hashlib.md5(str(self.generator.random.random()).encode('utf-8'))
        if raw_output:
            return res.digest()
        return res.hexdigest()

    def sha1(self, raw_output=False):
        """
        Calculates the sha1 hash of a given string
        :example 'b5d86317c2a144cd04d0d7c03b2b02666fafadf2'
        """
        res = hashlib.sha1(str(self.generator.random.random()).encode('utf-8'))
        if raw_output:
            return res.digest()
        return res.hexdigest()

    def sha256(self, raw_output=False):
        """
        Calculates the sha256 hash of a given string
        :example '85086017559ccc40638fcde2fecaf295e0de7ca51b7517b6aebeaaf75b4d4654'
        """
        res = hashlib.sha256(str(self.generator.random.random()).encode('utf-8'))
        if raw_output:
            return res.digest()
        return res.hexdigest()

    def locale(self):
        language_code = self.language_code()
        return language_code + '_' + self.random_element(
            Provider.language_locale_codes[language_code]
        )

    def language_code(self):
        return self.random_element(Provider.language_locale_codes.keys())

    def uuid4(self):
        """
        Generates a random UUID4 string.
        """
        # Based on http://stackoverflow.com/q/41186818
        return str(uuid.UUID(int=self.generator.random.getrandbits(128)))

    def password(self, length=10, special_chars=True, digits=True, upper_case=True, lower_case=True):
        """
        Generates a random password.
        @param length: Integer. Length of a password
        @param special_chars: Boolean. Whether to use special characters !@#$%^&*()_+
        @param digits: Boolean. Whether to use digits
        @param upper_case: Boolean. Whether to use upper letters
        @param lower_case: Boolean. Whether to use lower letters
        @return: String. Random password
        """
        choices = ""
        required_tokens = []
        if special_chars:
            required_tokens.append(self.generator.random.choice("!@#$%^&*()_+"))
            choices += "!@#$%^&*()_+"
        if digits:
            required_tokens.append(self.generator.random.choice(string.digits))
            choices += string.digits
        if upper_case:
            required_tokens.append(self.generator.random.choice(string.ascii_uppercase))
            choices += string.ascii_uppercase
        if lower_case:
            required_tokens.append(self.generator.random.choice(string.ascii_lowercase))
            choices += string.ascii_lowercase

        assert len(required_tokens) <= length, "Required length is shorter than required characters"

        # Generate a first version of the password
        chars = [self.generator.random.choice(choices) for x in range(length)]

        # Pick some unique locations
        random_indexes = set()
        while len(random_indexes) < len(required_tokens):
            random_indexes.add(self.generator.random.randint(0, len(chars) - 1))

        # Replace them with the required characters
        for i, index in enumerate(random_indexes):
            chars[index] = required_tokens[i]

        return ''.join(chars)
